@@ -1,4 +1,4 @@
-// Copyright 2005-2019 The Mumble Developers. All rights reserved.
+// Copyright 2007-2022 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
@@ -8,34 +8,34 @@
 
 #define _UNICODE
 #ifdef _WIN32_WINNT
-# undef _WIN32_WINNT
+#	undef _WIN32_WINNT
 #endif
-#define  _WIN32_WINNT 0x0501
-#include <stdio.h>
-#include <stdarg.h>
-#include <ctype.h>
+#define _WIN32_WINNT 0x0501
 #include <windows.h>
-#include <math.h>
-#include <map>
-#include <vector>
-#include <string>
-#include <boost/optional.hpp>
-#include "overlay.h"
 #include "HardHook.h"
 #include "ods.h"
+#include "overlay.h"
+#include <boost/optional.hpp>
+#include <cmath>
+#include <ctype.h>
+#include <map>
+#include <stdarg.h>
+#include <stdio.h>
+#include <string>
+#include <vector>
 
-#define lround(x) static_cast<long int>((x) + (((x) >= 0.0) ? 0.5 : -0.5))
+#define lround(x) static_cast< long int >((x) + (((x) >= 0.0) ? 0.5 : -0.5))
 
 #define ARRAY_SIZE_BYTES(x) sizeof(x)
-#define ARRAY_NUM_ELEMENTS(x) (sizeof(x)/sizeof((x)[0]))
+#define ARRAY_NUM_ELEMENTS(x) (sizeof(x) / sizeof((x)[0]))
 
 using namespace std;
 
 void __cdecl ods(const char *format, ...);
 
-const int MODULEFILEPATH_BUFLEN = 2048;
-const int PROCNAMEFILEPATH_BUFLEN = 1024;
-const int PROCNAMEFILEPATH_EXTENDED_EXTLEN = 64;
+const int MODULEFILEPATH_BUFLEN                   = 2048;
+const int PROCNAMEFILEPATH_BUFLEN                 = 1024;
+const int PROCNAMEFILEPATH_EXTENDED_EXTLEN        = 64;
 const int PROCNAMEFILEPATH_EXTENDED_BUFFER_BUFLEN = PROCNAMEFILEPATH_BUFLEN + PROCNAMEFILEPATH_EXTENDED_EXTLEN;
 
 struct Direct3D9Data {
@@ -71,36 +71,39 @@ struct SharedData {
 };
 
 class Mutex {
-	protected:
-		static CRITICAL_SECTION cs;
-	public:
-		static void init();
-		Mutex();
-		~Mutex();
+protected:
+	static CRITICAL_SECTION cs;
+
+public:
+	static void init();
+	Mutex();
+	~Mutex();
 };
 
 class Pipe {
-	private:
-		HANDLE hSocket;
-		HANDLE hMemory;
+private:
+	HANDLE hSocket;
+	HANDLE hMemory;
 
-		void release();
-	protected:
-		unsigned int uiWidth, uiHeight;
-		unsigned int uiLeft, uiTop, uiRight, uiBottom;
-		unsigned char *a_ucTexture;
-		DWORD dwAlreadyRead;
-		OverlayMsg omMsg;
+	void release();
 
-		void checkMessage(unsigned int w, unsigned int h);
-		bool sendMessage(const OverlayMsg &m);
-		virtual void blit(unsigned int x, unsigned int y, unsigned int w, unsigned int h) = 0;
-		virtual void setRect() = 0;
-		virtual void newTexture(unsigned int w, unsigned int h) = 0;
-		Pipe();
-		virtual ~Pipe();
-	public:
-		void disconnect();
+protected:
+	unsigned int uiWidth, uiHeight;
+	unsigned int uiLeft, uiTop, uiRight, uiBottom;
+	unsigned char *a_ucTexture;
+	DWORD dwAlreadyRead;
+	OverlayMsg omMsg;
+
+	void checkMessage(unsigned int w, unsigned int h);
+	bool sendMessage(const OverlayMsg &m);
+	virtual void blit(unsigned int x, unsigned int y, unsigned int w, unsigned int h) = 0;
+	virtual void setRect()                                                            = 0;
+	virtual void newTexture(unsigned int w, unsigned int h)                           = 0;
+	Pipe();
+	virtual ~Pipe();
+
+public:
+	void disconnect();
 };
 
 // From lib.cpp
@@ -136,12 +139,15 @@ extern BOOL bIsWin8;
 /// @param logPrefix Used for debug logging.
 /// @param fnName name of the method fnptr points to. used for debug logging
 /// @return true if the module filepath of the function pointer matches the reference one
-extern bool IsFnInModule(voidFunc fnptr, wchar_t *refmodulepath, const std::string &logPrefix, const std::string &fnName);
+extern bool IsFnInModule(voidFunc fnptr, wchar_t *refmodulepath, const std::string &logPrefix,
+						 const std::string &fnName);
 
 // From lib.cpp
 /// Checks fnptr is in a loaded module with module path refmodulepath.
 ///
 /// @return Offset as int or < 0 on failure.
-extern boost::optional<size_t> GetFnOffsetInModule(voidFunc fnptr, wchar_t *refmodulepath, unsigned int refmodulepathLen, const std::string &logPrefix, const std::string &fnName);
+extern boost::optional< size_t > GetFnOffsetInModule(voidFunc fnptr, wchar_t *refmodulepath,
+													 unsigned int refmodulepathLen, const std::string &logPrefix,
+													 const std::string &fnName);
 
 #endif
