@@ -1,4 +1,4 @@
-// Copyright 2005-2019 The Mumble Developers. All rights reserved.
+// Copyright 2017-2022 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
@@ -8,10 +8,9 @@
 
 static const char *overlayWhitelist[] = {
 	// We can't whitelist the GW2 launcher
-	"gw2.exe",
-	"gw2-64.exe",
+	"gw2.exe", "gw2-64.exe",
 
-	NULL
+	nullptr
 };
 
 #endif
