@@ -1,15 +1,19 @@
-// Copyright 2005-2019 The Mumble Developers. All rights reserved.
+// Copyright 2009-2022 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
 
-#include "../mumble_plugin_win32.h"
+#define MUMBLE_ALLOW_DEPRECATED_LEGACY_PLUGIN_API
+#include "mumble_legacy_plugin.h"
 
-static int fetch(float *avatar_pos, float *avatar_front, float *avatar_top, float *camera_pos, float *camera_front, float *camera_top, std::string &, std::wstring &) {
+#include "mumble_positional_audio_main.h"
+
+static int fetch(float *avatar_pos, float *avatar_front, float *avatar_top, float *camera_pos, float *camera_front,
+				 float *camera_top, std::string &, std::wstring &) {
 	float viewHor, viewVer;
 	char state;
 
-	for (int i=0;i<3;i++)
+	for (int i = 0; i < 3; i++)
 		avatar_pos[i] = avatar_front[i] = avatar_top[i] = camera_pos[i] = camera_front[i] = camera_top[i] = 0.0f;
 
 	bool ok;
@@ -28,7 +32,7 @@ static int fetch(float *avatar_pos, float *avatar_front, float *avatar_top, floa
 			0x007F7A34		byte	Magical state value
 	*/
 	ok = peekProc(0x007F8AB4, &state, 1); // Magical state value
-	if (! ok)
+	if (!ok)
 		return false;
 	/*
 		state value is:
@@ -42,13 +46,13 @@ static int fetch(float *avatar_pos, float *avatar_front, float *avatar_top, floa
 	if (state != 1)
 		return true; // This results in all vectors beeing zero which tells mumble to ignore them.
 
-	ok = peekProc(0x008F1FF8, avatar_pos+2, 4) &&	//Z
-	     peekProc(0x008F1FFC, avatar_pos, 4) &&	//X
-	     peekProc(0x008F2000, avatar_pos+1, 4) && //Y
-	     peekProc(0x008F2008, &viewHor, 4) && //Hor
-	     peekProc(0x008F2004, &viewVer, 4); //Ver
+	ok = peekProc(0x008F1FF8, avatar_pos + 2, 4) && // Z
+		 peekProc(0x008F1FFC, avatar_pos, 4) &&     // X
+		 peekProc(0x008F2000, avatar_pos + 1, 4) && // Y
+		 peekProc(0x008F2008, &viewHor, 4) &&       // Hor
+		 peekProc(0x008F2004, &viewVer, 4);         // Ver
 
-	if (! ok)
+	if (!ok)
 		return false;
 
 	// Scale Coordinates
@@ -61,9 +65,9 @@ static int fetch(float *avatar_pos, float *avatar_front, float *avatar_top, floa
 				  decreasing when going down
 	   40 units = 1 meter (not confirmed)
 	*/
-	for (int i=0;i<3;i++)
-		avatar_pos[i]/=40.0f; // Scale to meters
-	avatar_pos[0]*=(-1.0f); // Convert right to left handed
+	for (int i = 0; i < 3; i++)
+		avatar_pos[i] /= 40.0f; // Scale to meters
+	avatar_pos[0] *= (-1.0f);   // Convert right to left handed
 
 	avatar_top[2] = -1; // Head movement is in front vector
 
@@ -80,24 +84,24 @@ static int fetch(float *avatar_pos, float *avatar_front, float *avatar_top, floa
 				   270° when facing East
 	   Increasing when turning left.
 	*/
-	viewVer *= static_cast<float>(M_PI / 180.0f);
-	viewHor *= static_cast<float>(M_PI / 180.0f);
+	viewVer *= static_cast< float >(M_PI / 180.0f);
+	viewHor *= static_cast< float >(M_PI / 180.0f);
 
 	avatar_front[0] = -sin(viewHor) * cos(viewVer);
 	avatar_front[1] = -sin(viewVer);
 	avatar_front[2] = cos(viewHor) * cos(viewVer);
 
-	for (int i=0;i<3;i++) {
-		camera_pos[i] = avatar_pos[i];
+	for (int i = 0; i < 3; i++) {
+		camera_pos[i]   = avatar_pos[i];
 		camera_front[i] = avatar_front[i];
-		camera_top[i] = avatar_top[i];
+		camera_top[i]   = avatar_top[i];
 	}
 
 	return true;
 }
 
-static int trylock(const std::multimap<std::wstring, unsigned long long int> &pids) {
-	if (! initialize(pids, L"iw4mp.exe"))
+static int trylock(const std::multimap< std::wstring, unsigned long long int > &pids) {
+	if (!initialize(pids, L"iw4mp.exe"))
 		return false;
 
 	float apos[3], afront[3], atop[3], cpos[3], cfront[3], ctop[3];
@@ -113,33 +117,21 @@ static int trylock(const std::multimap<std::wstring, unsigned long long int> &pi
 }
 
 static const std::wstring longdesc() {
-	return std::wstring(L"Supports Call of Duty: Modern Warfare 2 MP v1.2.208 only. No context or identity support yet.");
+	return std::wstring(
+		L"Supports Call of Duty: Modern Warfare 2 MP v1.2.208 only. No context or identity support yet.");
 }
 
 static std::wstring description(L"Call of Duty: Modern Warfare 2 MP v1.2.208");
 static std::wstring shortname(L"Call of Duty: Modern Warfare 2 MP");
 
 static int trylock1() {
-	return trylock(std::multimap<std::wstring, unsigned long long int>());
+	return trylock(std::multimap< std::wstring, unsigned long long int >());
 }
 
-static MumblePlugin codmw2plug = {
-	MUMBLE_PLUGIN_MAGIC,
-	description,
-	shortname,
-	NULL,
-	NULL,
-	trylock1,
-	generic_unlock,
-	longdesc,
-	fetch
-};
+static MumblePlugin codmw2plug = { MUMBLE_PLUGIN_MAGIC, description, shortname, nullptr, nullptr, trylock1,
+								   generic_unlock,      longdesc,    fetch };
 
-static MumblePlugin2 codmw2plug2 = {
-	MUMBLE_PLUGIN_MAGIC_2,
-	MUMBLE_PLUGIN_VERSION,
-	trylock
-};
+static MumblePlugin2 codmw2plug2 = { MUMBLE_PLUGIN_MAGIC_2, MUMBLE_PLUGIN_VERSION, trylock };
 
 extern "C" MUMBLE_PLUGIN_EXPORT MumblePlugin *getMumblePlugin() {
 	return &codmw2plug;
