@@ -1,20 +1,24 @@
-// Copyright 2005-2019 The Mumble Developers. All rights reserved.
+// Copyright 2009-2022 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
 
-#include "../mumble_plugin_win32.h"
+#define MUMBLE_ALLOW_DEPRECATED_LEGACY_PLUGIN_API
+#include "mumble_legacy_plugin.h"
+
+#include "mumble_positional_audio_main.h"
 
 using namespace std;
 
 procptr_t pos1ptr, pos2ptr, pos3ptr, rot1ptr, rot2ptr;
 
-static int fetch(float *avatar_pos, float *avatar_front, float *avatar_top, float *camera_pos, float *camera_front, float *camera_top, std::string &context, std::wstring &) {
+static int fetch(float *avatar_pos, float *avatar_front, float *avatar_top, float *camera_pos, float *camera_front,
+				 float *camera_top, std::string &context, std::wstring &) {
 	char menustate;
 	char ccontext[128];
 
 	float viewHor, viewVer;
-	for (int i=0;i<3;i++)
+	for (int i = 0; i < 3; i++)
 		avatar_pos[i] = avatar_front[i] = avatar_top[i] = camera_pos[i] = camera_front[i] = camera_top[i] = 0.0f;
 
 	bool ok;
@@ -32,27 +36,27 @@ static int fetch(float *avatar_pos, float *avatar_front, float *avatar_top, floa
 			0x013E8D18		byte	Magic value (32 ingame / 0 spectating)
 	*/
 	ok = peekProc(0x00801BA4, &menustate, 1);
-	if (! ok)
+	if (!ok)
 		return false;
 	if (menustate == 0)
 		return true;
 
-	ok = peekProc(pos1ptr, avatar_pos+1, 4) &&	//Y
-	     peekProc(pos2ptr, avatar_pos, 4) &&	//X
-	     peekProc(pos3ptr, avatar_pos+2, 4) && //Z
-	     peekProc(rot1ptr, &viewHor, 4) && //Hor
-	     peekProc(rot2ptr, &viewVer, 4) && //Ver
-	     peekProc(0x0122E0B8, ccontext, 128);
+	ok = peekProc(pos1ptr, avatar_pos + 1, 4) && // Y
+		 peekProc(pos2ptr, avatar_pos, 4) &&     // X
+		 peekProc(pos3ptr, avatar_pos + 2, 4) && // Z
+		 peekProc(rot1ptr, &viewHor, 4) &&       // Hor
+		 peekProc(rot2ptr, &viewVer, 4) &&       // Ver
+		 peekProc(0x0122E0B8, ccontext, 128);
 
-	if (! ok)
+	if (!ok)
 		return false;
 
 	avatar_top[2] = -1; // Head movement is in front vector
 
 	ccontext[127] = 0;
-	context = std::string(ccontext);
+	context       = std::string(ccontext);
 
-	if (context.find(':')==string::npos)
+	if (context.find(':') == string::npos)
 		context.append(":27733");
 
 	/*
@@ -78,26 +82,26 @@ static int fetch(float *avatar_pos, float *avatar_front, float *avatar_top, floa
 					+180 when facing west
 	   Increasing when turning left.
 	*/
-	viewVer *= static_cast<float>(M_PI / 180.0f);
-	viewHor *= static_cast<float>(M_PI / 180.0f);
+	viewVer *= static_cast< float >(M_PI / 180.0f);
+	viewHor *= static_cast< float >(M_PI / 180.0f);
 
 	avatar_front[0] = -sin(viewHor) * cos(viewVer);
 	avatar_front[1] = -sin(viewVer);
 	avatar_front[2] = cos(viewHor) * cos(viewVer);
 
-	for (int i=0;i<3;i++) {
-		camera_pos[i] = avatar_pos[i];
+	for (int i = 0; i < 3; i++) {
+		camera_pos[i]   = avatar_pos[i];
 		camera_front[i] = avatar_front[i];
-		camera_top[i] = avatar_top[i];
+		camera_top[i]   = avatar_top[i];
 	}
 
 	return true;
 }
 
-static int trylock(const std::multimap<std::wstring, unsigned long long int> &pids) {
+static int trylock(const std::multimap< std::wstring, unsigned long long int > &pids) {
 	pos1ptr = pos2ptr = pos3ptr = rot1ptr = rot2ptr = 0;
 
-	if (! initialize(pids, L"etqw.exe", L"gamex86.dll"))
+	if (!initialize(pids, L"etqw.exe", L"gamex86.dll"))
 		return false;
 
 	pos1ptr = pModule + 0x74EABC;
@@ -126,26 +130,13 @@ static std::wstring description(L"Enemy Territory: Quake Wars v1.50");
 static std::wstring shortname(L"Enemy Territory: Quake Wars");
 
 static int trylock1() {
-	return trylock(std::multimap<std::wstring, unsigned long long int>());
+	return trylock(std::multimap< std::wstring, unsigned long long int >());
 }
 
-static MumblePlugin etqwplug = {
-	MUMBLE_PLUGIN_MAGIC,
-	description,
-	shortname,
-	NULL,
-	NULL,
-	trylock1,
-	generic_unlock,
-	longdesc,
-	fetch
-};
+static MumblePlugin etqwplug = { MUMBLE_PLUGIN_MAGIC, description, shortname, nullptr, nullptr, trylock1,
+								 generic_unlock,      longdesc,    fetch };
 
-static MumblePlugin2 etqwplug2 = {
-	MUMBLE_PLUGIN_MAGIC_2,
-	MUMBLE_PLUGIN_VERSION,
-	trylock
-};
+static MumblePlugin2 etqwplug2 = { MUMBLE_PLUGIN_MAGIC_2, MUMBLE_PLUGIN_VERSION, trylock };
 
 extern "C" MUMBLE_PLUGIN_EXPORT MumblePlugin *getMumblePlugin() {
 	return &etqwplug;
