@@ -1,9 +1,9 @@
-// Copyright 2005-2019 The Mumble Developers. All rights reserved.
+// Copyright 2012-2022 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
 
-/* Copyright (C) 2012, dark_skeleton (d-rez) <dark.skeleton@gmail.com> 
+/* Copyright (C) 2012, dark_skeleton (d-rez) <dark.skeleton@gmail.com>
    Copyright (C) 2005-2012, Thorvald Natvig <thorvald@natvig.com>
 
    All rights reserved.
@@ -13,13 +13,13 @@
    are met:
 
    - Redistributions of source code must retain the above copyright notice,
-     this list of conditions and the following disclaimer.
+	 this list of conditions and the following disclaimer.
    - Redistributions in binary form must reproduce the above copyright notice,
-     this list of conditions and the following disclaimer in the documentation
-     and/or other materials provided with the distribution.
+	 this list of conditions and the following disclaimer in the documentation
+	 and/or other materials provided with the distribution.
    - Neither the name of the Mumble Developers nor the names of its
-     contributors may be used to endorse or promote products derived from this
-     software without specific prior written permission.
+	 contributors may be used to endorse or promote products derived from this
+	 software without specific prior written permission.
 
    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
    ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
@@ -34,20 +34,26 @@
    SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
-#include "../mumble_plugin_win32.h"
+#define MUMBLE_ALLOW_DEPRECATED_LEGACY_PLUGIN_API
+#include "mumble_legacy_plugin.h"
+
+#include "mumble_positional_audio_main.h"
 
 /*
-	Arrays of bytes to find addresses accessed by respective functions so we don't have to blindly search for addresses after every update
-	Remember to disable scanning only the writable memory in CE! We're searching for functions here, not values!
-	
+	Arrays of bytes to find addresses accessed by respective functions so we don't have to blindly search for addresses
+   after every update Remember to disable scanning only the writable memory in CE! We're searching for functions here,
+   not values!
+
 	Camera and avatar position function:		89 10 8B 57 04 89 50 04 8B 57 08 89 50 08 DF E0 F6 C4 01
 		1) Camera position
 		2) Camera position (?)
 		3) Avatar position
 	Camera front vector function:				46 BF 00 89 15 (disassemble, then go up a few times in disassembly)
 	Unit front vector function:					89 1E 8B 5F 04 89 5E 04 8B 7F 08 89 7E 08 8B 7D 10 8D 71 28
-		To find the right front vector pointer, you'll need to make a pointer scan for the address that gets updated only when >you< move, using different characters in different locations. It should leave you with only two possible pointers after just 2 scans.
-	Location function:							8D 14 DB 8D 34 90 8D 4E 14 (target instruction is the one above the one you find)
+		To find the right front vector pointer, you'll need to make a pointer scan for the address that gets updated
+   only when >you< move, using different characters in different locations. It should leave you with only two possible
+   pointers after just 2 scans. Location function:							8D 14 DB 8D 34 90 8D 4E 14 (target
+   instruction is the one above the one you find)
 	Area function:								A3 58 11 A3 00 E8 B8 02 00 00 BA 37 00 00 00 8B CE
 
 	Valid addresses from build b36001
@@ -60,8 +66,9 @@
 	Area:										0xa31158
 
 	No need to care about top vector since the game doesn't use it anyway
-	Context is defined based on location + area combo. This is not enough to be unique in most cases (it doesn't let us distinguish between districts and servers), but it's better than nothing
-	
+	Context is defined based on location + area combo. This is not enough to be unique in most cases (it doesn't let us
+   distinguish between districts and servers), but it's better than nothing
+
 	Location Pointer:
 		25 or 26: Explorable Area / Mission
 		26 or 27: Town
@@ -69,27 +76,30 @@
 		1 when not logged in (in login screen)
 
 	Area Pointer:
-		This is a 4-byte decimal stating which area we are in. Note however, that some missions have the same area assigned as cities, therefore we need our Location Pointer to distinguish where we are exactly to specify context properly.
+		This is a 4-byte decimal stating which area we are in. Note however, that some missions have the same area
+   assigned as cities, therefore we need our Location Pointer to distinguish where we are exactly to specify context
+   properly.
 
 */
 
-static procptr_t camptr = 0xa30274;
-static procptr_t posptr = 0xa302a4;
+static procptr_t camptr      = 0xa30274;
+static procptr_t posptr      = 0xa302a4;
 static procptr_t camfrontptr = 0xbf46b8;
-static procptr_t frontptr_ = 0xd55610;
+static procptr_t frontptr_   = 0xd55610;
 static procptr_t frontptr;
 
 static procptr_t locationptr = 0xa3fa08;
-static procptr_t areaptr = 0xa31158;
+static procptr_t areaptr     = 0xa31158;
 
 static char prev_location;
 static int prev_areaid;
 
-static bool calcout(float *pos, float *front, float *cam, float *camfront, float *opos, float *ofront, float *ocam, float *ocamfront) {
-
-	// Seems Guild Wars is in... inches, yeah :) ---> same as in GW2, proof here: http://www.guildwars2guru.com/topic/21519-reddit-ama-all-questions-answers (question #31)
-	// coordinate Y is swapped with Z
-	// Y is negative (looks like somewhere underground is 0.00 and land is for example -120. When we climb up a hill, it decreases (e.g. -130), and when we descent, it goes higher (e.g. -100)
+static bool calcout(float *pos, float *front, float *cam, float *camfront, float *opos, float *ofront, float *ocam,
+					float *ocamfront) {
+	// Seems Guild Wars is in... inches, yeah :) ---> same as in GW2, proof here:
+	// http://www.guildwars2guru.com/topic/21519-reddit-ama-all-questions-answers (question #31) coordinate Y is swapped
+	// with Z Y is negative (looks like somewhere underground is 0.00 and land is for example -120. When we climb up a
+	// hill, it decreases (e.g. -130), and when we descent, it goes higher (e.g. -100)
 
 	opos[0] = pos[0] / 39.37f;
 	opos[1] = -pos[2] / 39.37f;
@@ -110,8 +120,7 @@ static bool calcout(float *pos, float *front, float *cam, float *camfront, float
 	return true;
 }
 
-static bool refreshPointers(void)
-{
+static bool refreshPointers(void) {
 	frontptr = 0;
 
 	frontptr = peekProcPtr(frontptr_);
@@ -128,8 +137,9 @@ static bool refreshPointers(void)
 	return true;
 }
 
-static int fetch(float *avatar_pos, float *avatar_front, float *avatar_top, float *camera_pos, float *camera_front, float *camera_top, std::string &context, std::wstring &/*identity*/) {
-	for (int i=0; i<3; i++)
+static int fetch(float *avatar_pos, float *avatar_front, float *avatar_top, float *camera_pos, float *camera_front,
+				 float *camera_top, std::string &context, std::wstring & /*identity*/) {
+	for (int i = 0; i < 3; i++)
 		avatar_pos[i] = avatar_front[i] = avatar_top[i] = camera_pos[i] = camera_front[i] = camera_top[i] = 0.0f;
 
 	bool ok;
@@ -137,21 +147,19 @@ static int fetch(float *avatar_pos, float *avatar_front, float *avatar_top, floa
 	char location;
 	int areaid;
 
-	ok = peekProc(camptr, cam) &&
-		 peekProc(posptr, pos) &&
-		 peekProc(camfrontptr, camfront) &&
-		 peekProc(locationptr, &location, 1) &&
-		 peekProc(areaptr, &areaid, 4);
+	ok = peekProc(camptr, cam) && peekProc(posptr, pos) && peekProc(camfrontptr, camfront)
+		 && peekProc(locationptr, &location, 1) && peekProc(areaptr, &areaid, 4);
 
 	if (!ok) // First we check, if the game is even running or if we should unlink because it's not / it's broken
 		return false;
 
-	ok = refreshPointers(); // yes, we need to do this pretty often since the pointer gets wiped and changed evey time you leave a world instance (that means on loading screens etc)
-	if (!ok) { // Next we check, if we're inside the game or in menus/in a loading screen
+	ok = refreshPointers(); // yes, we need to do this pretty often since the pointer gets wiped and changed evey time
+							// you leave a world instance (that means on loading screens etc)
+	if (!ok) {              // Next we check, if we're inside the game or in menus/in a loading screen
 		context.clear();
 		return true; // don't report positional data but stay linked to avoid unnecessary unlinking on loading screens
-	}
-	else { // If we're inside the game, try to peekProc the last value we need or unlink (again, in case something went wrong)
+	} else { // If we're inside the game, try to peekProc the last value we need or unlink (again, in case something
+			 // went wrong)
 		if (!peekProc(frontptr, front))
 			return false;
 	}
@@ -159,33 +167,32 @@ static int fetch(float *avatar_pos, float *avatar_front, float *avatar_top, floa
 	calcout(pos, front, cam, camfront, avatar_pos, avatar_front, camera_pos, camera_front);
 
 	if (areaid != prev_areaid || location != prev_location) {
-		context.clear();
-
-		prev_areaid = areaid;
+		prev_areaid   = areaid;
 		prev_location = location;
 
-		char buffer[50];
-		sprintf_s(buffer, sizeof(buffer), "{\"instance\": \"%d:%d\"}", areaid, static_cast<int>(location));
-		context.assign(buffer);
+		std::ostringstream contextstream;
+		contextstream << "{\"instance\": \"" << areaid << ":" << static_cast< int >(location) << "\"}";
+		context = contextstream.str();
 	}
+
 	return true;
 }
 
-static int trylock(const std::multimap<std::wstring, unsigned long long int> &pids) {
-
-	if (! initialize(pids, L"Gw.exe"))
+static int trylock(const std::multimap< std::wstring, unsigned long long int > &pids) {
+	if (!initialize(pids, L"Gw.exe"))
 		return false;
 
-	float cam[3], pos[3], front[3],camfront[3], top[3], camtop[3];
+	float cam[3], pos[3], front[3], camfront[3], top[3], camtop[3];
 	std::string context;
 	std::wstring identity;
 
-	prev_areaid = 0;
+	prev_areaid   = 0;
 	prev_location = 0;
 
 	if (fetch(pos, front, top, cam, camfront, camtop, context, identity)) {
-		prev_areaid = 0;
-		prev_location = 0; // we need to do this again since fetch() above overwrites this (which results in empty context until next change)
+		prev_areaid   = 0;
+		prev_location = 0; // we need to do this again since fetch() above overwrites this (which results in empty
+						   // context until next change)
 		return true;
 	} else {
 		generic_unlock();
@@ -201,26 +208,13 @@ static std::wstring description(L"Guild Wars b36001");
 static std::wstring shortname(L"Guild Wars");
 
 static int trylock1() {
-	return trylock(std::multimap<std::wstring, unsigned long long int>());
+	return trylock(std::multimap< std::wstring, unsigned long long int >());
 }
 
-static MumblePlugin gwplug = {
-	MUMBLE_PLUGIN_MAGIC,
-	description,
-	shortname,
-	NULL,
-	NULL,
-	trylock1,
-	generic_unlock,
-	longdesc,
-	fetch
-};
+static MumblePlugin gwplug = { MUMBLE_PLUGIN_MAGIC, description, shortname, nullptr, nullptr, trylock1,
+							   generic_unlock,      longdesc,    fetch };
 
-static MumblePlugin2 gwplug2 = {
-	MUMBLE_PLUGIN_MAGIC_2,
-	MUMBLE_PLUGIN_VERSION,
-	trylock
-};
+static MumblePlugin2 gwplug2 = { MUMBLE_PLUGIN_MAGIC_2, MUMBLE_PLUGIN_VERSION, trylock };
 
 extern "C" MUMBLE_PLUGIN_EXPORT MumblePlugin *getMumblePlugin() {
 	return &gwplug;
