@@ -1,12 +1,13 @@
-// Copyright 2005-2019 The Mumble Developers. All rights reserved.
+// Copyright 2013-2022 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
 
-#include "mumble_plugin.h"
+#define MUMBLE_ALLOW_DEPRECATED_LEGACY_PLUGIN_API
+#include "mumble_legacy_plugin.h"
 
 #ifndef NULL_DESC
-#define NULL_DESC L"Retracted plugin"
+#	define NULL_DESC L"Retracted plugin"
 #endif // NULL_DESC
 
 static int fetch(float *, float *, float *, float *, float *, float *, std::string &, std::wstring &) {
@@ -27,18 +28,9 @@ static std::wstring description(NULL_DESC);
 static std::wstring shortname(L"Retracted");
 
 static MumblePlugin nullplug = {
-	MUMBLE_PLUGIN_MAGIC,
-	description,
-	shortname,
-	NULL,
-	NULL,
-	trylock,
-	NULL,
-	longdesc,
-	fetch
+	MUMBLE_PLUGIN_MAGIC, description, shortname, nullptr, nullptr, trylock, nullptr, longdesc, fetch
 };
 
 extern "C" MUMBLE_PLUGIN_EXPORT MumblePlugin *getMumblePlugin() {
 	return &nullplug;
 }
-
