@@ -1,60 +1,62 @@
-// Copyright 2005-2019 The Mumble Developers. All rights reserved.
+// Copyright 2007-2022 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
 
-#ifdef MUMBLE
-	#include "mumble_pch.hpp"
-#else
-	#include "murmur_pch.h"
-#endif
-
-#ifdef Q_OS_UNIX
-#include <sys/socket.h>
-#include <sys/types.h>
-#include <netinet/in.h>
-#include <netinet/tcp.h>
-#endif
-
 #include "Connection.h"
-#include "Message.h"
-#include "SSL.h"
 #include "Mumble.pb.h"
+#include "SSL.h"
 
+#include <QtCore/QtEndian>
+#include <QtNetwork/QHostAddress>
 
 #ifdef Q_OS_WIN
-HANDLE Connection::hQoS = NULL;
+#	include <qos2.h>
+#else
+#	include <netinet/in.h>
+#	include <netinet/tcp.h>
+#	include <sys/socket.h>
+#	include <sys/types.h>
+#endif
+
+#ifdef Q_OS_WIN
+HANDLE Connection::hQoS = nullptr;
 #endif
 
 Connection::Connection(QObject *p, QSslSocket *qtsSock) : QObject(p) {
 	qtsSocket = qtsSock;
 	qtsSocket->setParent(this);
-	iPacketLength = -1;
+	iPacketLength        = -1;
 	bDisconnectedEmitted = false;
+	csCrypt              = std::make_unique< CryptStateOCB2 >();
 
 	static bool bDeclared = false;
-	if (! bDeclared) {
+	if (!bDeclared) {
 		bDeclared = true;
-		qRegisterMetaType<QAbstractSocket::SocketError>("QAbstractSocket::SocketError");
+		qRegisterMetaType< QAbstractSocket::SocketError >("QAbstractSocket::SocketError");
 	}
 
-	connect(qtsSocket, SIGNAL(error(QAbstractSocket::SocketError)), this, SLOT(socketError(QAbstractSocket::SocketError)));
+	int nodelay = 1;
+	setsockopt(static_cast< int >(qtsSocket->socketDescriptor()), IPPROTO_TCP, TCP_NODELAY,
+			   reinterpret_cast< char * >(&nodelay), static_cast< socklen_t >(sizeof(nodelay)));
+
+	connect(qtsSocket, SIGNAL(error(QAbstractSocket::SocketError)), this,
+			SLOT(socketError(QAbstractSocket::SocketError)));
 	connect(qtsSocket, SIGNAL(encrypted()), this, SIGNAL(encrypted()));
 	connect(qtsSocket, SIGNAL(readyRead()), this, SLOT(socketRead()));
 	connect(qtsSocket, SIGNAL(disconnected()), this, SLOT(socketDisconnected()));
-	connect(qtsSocket, SIGNAL(sslErrors(const QList<QSslError> &)), this, SLOT(socketSslErrors(const QList<QSslError> &)));
+	connect(qtsSocket, SIGNAL(sslErrors(const QList< QSslError > &)), this,
+			SLOT(socketSslErrors(const QList< QSslError > &)));
 	qtLastPacket.restart();
 #ifdef Q_OS_WIN
 	dwFlow = 0;
 #endif
-
-
 }
 
 Connection::~Connection() {
 #ifdef Q_OS_WIN
 	if (dwFlow && hQoS) {
-		if (! QOSRemoveSocketFromFlow(hQoS, 0, dwFlow, 0))
+		if (!QOSRemoveSocketFromFlow(hQoS, 0, dwFlow, 0))
 			qWarning("Connection: Failed to remove flow from QoS");
 	}
 #endif
@@ -62,28 +64,29 @@ Connection::~Connection() {
 
 void Connection::setToS() {
 #if defined(Q_OS_WIN)
-	if (dwFlow || ! hQoS)
+	if (dwFlow || !hQoS)
 		return;
 
 	dwFlow = 0;
-	if (! QOSAddSocketToFlow(hQoS, qtsSocket->socketDescriptor(), NULL, QOSTrafficTypeAudioVideo, QOS_NON_ADAPTIVE_FLOW, reinterpret_cast<PQOS_FLOWID>(&dwFlow)))
+	if (!QOSAddSocketToFlow(hQoS, qtsSocket->socketDescriptor(), nullptr, QOSTrafficTypeAudioVideo,
+							QOS_NON_ADAPTIVE_FLOW, reinterpret_cast< PQOS_FLOWID >(&dwFlow)))
 		qWarning("Connection: Failed to add flow to QOS");
 #elif defined(Q_OS_UNIX)
 	int val = 0xa0;
-	if (setsockopt(static_cast<int>(qtsSocket->socketDescriptor()), IPPROTO_IP, IP_TOS, &val, sizeof(val))) {
+	if (setsockopt(static_cast< int >(qtsSocket->socketDescriptor()), IPPROTO_IP, IP_TOS, &val, sizeof(val))) {
 		val = 0x60;
-		if (setsockopt(static_cast<int>(qtsSocket->socketDescriptor()), IPPROTO_IP, IP_TOS, &val, sizeof(val)))
+		if (setsockopt(static_cast< int >(qtsSocket->socketDescriptor()), IPPROTO_IP, IP_TOS, &val, sizeof(val)))
 			qWarning("Connection: Failed to set TOS for TCP Socket");
 	}
-#if defined(SO_PRIORITY)
+#	if defined(SO_PRIORITY)
 	socklen_t optlen = sizeof(val);
-	if (getsockopt(static_cast<int>(qtsSocket->socketDescriptor()), SOL_SOCKET, SO_PRIORITY, &val, &optlen) == 0) {
+	if (getsockopt(static_cast< int >(qtsSocket->socketDescriptor()), SOL_SOCKET, SO_PRIORITY, &val, &optlen) == 0) {
 		if (val == 0) {
 			val = 6;
-			setsockopt(static_cast<int>(qtsSocket->socketDescriptor()), SOL_SOCKET, SO_PRIORITY, &val, sizeof(val));
+			setsockopt(static_cast< int >(qtsSocket->socketDescriptor()), SOL_SOCKET, SO_PRIORITY, &val, sizeof(val));
 		}
 	}
-#endif
+#	endif
 
 #endif
 }
@@ -116,9 +119,9 @@ void Connection::socketRead() {
 
 			unsigned char a_ucBuffer[6];
 
-			qtsSocket->read(reinterpret_cast<char *>(a_ucBuffer), 6);
-			uiType = qFromBigEndian<quint16>(&a_ucBuffer[0]);
-			iPacketLength = qFromBigEndian<quint32>(&a_ucBuffer[2]);
+			qtsSocket->read(reinterpret_cast< char * >(a_ucBuffer), 6);
+			m_type        = static_cast< Mumble::Protocol::TCPMessageType >(qFromBigEndian< quint16 >(&a_ucBuffer[0]));
+			iPacketLength = qFromBigEndian< quint32 >(&a_ucBuffer[2]);
 			iAvailable -= 6;
 		}
 
@@ -132,10 +135,10 @@ void Connection::socketRead() {
 		}
 
 		QByteArray qbaBuffer = qtsSocket->read(iPacketLength);
-		iPacketLength = -1;
+		iPacketLength        = -1;
 		iAvailable -= iPacketLength;
 
-		emit message(uiType, qbaBuffer);
+		emit message(m_type, qbaBuffer);
 	}
 }
 
@@ -143,7 +146,7 @@ void Connection::socketError(QAbstractSocket::SocketError err) {
 	emit connectionClosed(err, qtsSocket->errorString());
 }
 
-void Connection::socketSslErrors(const QList<QSslError> &qlErr) {
+void Connection::socketSslErrors(const QList< QSslError > &qlErr) {
 	emit handleSslErrors(qlErr);
 }
 
@@ -155,19 +158,26 @@ void Connection::socketDisconnected() {
 	emit connectionClosed(QAbstractSocket::UnknownSocketError, QString());
 }
 
-void Connection::messageToNetwork(const ::google::protobuf::Message &msg, unsigned int msgType, QByteArray &cache) {
+void Connection::messageToNetwork(const ::google::protobuf::Message &msg, Mumble::Protocol::TCPMessageType msgType,
+								  QByteArray &cache) {
+#if GOOGLE_PROTOBUF_VERSION >= 3004000
+	int len = msg.ByteSizeLong();
+#else
+	// ByteSize() has been deprecated as of protobuf v3.4
 	int len = msg.ByteSize();
+#endif
 	if (len > 0x7fffff)
 		return;
 	cache.resize(len + 6);
-	unsigned char *uc = reinterpret_cast<unsigned char *>(cache.data());
-	qToBigEndian<quint16>(static_cast<quint16>(msgType), & uc[0]);
-	qToBigEndian<quint32>(len, & uc[2]);
+	unsigned char *uc = reinterpret_cast< unsigned char * >(cache.data());
+	qToBigEndian< quint16 >(static_cast< quint16 >(msgType), &uc[0]);
+	qToBigEndian< quint32 >(len, &uc[2]);
 
 	msg.SerializeToArray(uc + 6, len);
 }
 
-void Connection::sendMessage(const ::google::protobuf::Message &msg, unsigned int msgType, QByteArray &cache) {
+void Connection::sendMessage(const ::google::protobuf::Message &msg, Mumble::Protocol::TCPMessageType msgType,
+							 QByteArray &cache) {
 	if (cache.isEmpty()) {
 		messageToNetwork(msg, msgType, cache);
 	}
@@ -176,7 +186,7 @@ void Connection::sendMessage(const ::google::protobuf::Message &msg, unsigned in
 }
 
 void Connection::sendMessage(const QByteArray &qbaMsg) {
-	if (! qbaMsg.isEmpty())
+	if (!qbaMsg.isEmpty())
 		qtsSocket->write(qbaMsg);
 }
 
@@ -184,17 +194,10 @@ void Connection::forceFlush() {
 	if (qtsSocket->state() != QAbstractSocket::ConnectedState)
 		return;
 
-	if (! qtsSocket->isEncrypted())
+	if (!qtsSocket->isEncrypted())
 		return;
 
-	int nodelay;
-
 	qtsSocket->flush();
-
-	nodelay = 1;
-	setsockopt(static_cast<int>(qtsSocket->socketDescriptor()), IPPROTO_TCP, TCP_NODELAY, reinterpret_cast<char *>(&nodelay), static_cast<socklen_t>(sizeof(nodelay)));
-	nodelay = 0;
-	setsockopt(static_cast<int>(qtsSocket->socketDescriptor()), IPPROTO_TCP, TCP_NODELAY, reinterpret_cast<char *>(&nodelay), static_cast<socklen_t>(sizeof(nodelay)));
 }
 
 void Connection::disconnectSocket(bool force) {
@@ -225,12 +228,14 @@ quint16 Connection::localPort() const {
 	return qtsSocket->localPort();
 }
 
-QList<QSslCertificate> Connection::peerCertificateChain() const {
-	const QSslCertificate cert = qtsSocket->peerCertificate();
-	if (cert.isNull())
-		return QList<QSslCertificate>();
-	else
-		return qtsSocket->peerCertificateChain() << cert;
+QList< QSslCertificate > Connection::peerCertificateChain() const {
+	// The documentation of QSslSocket::peerCertificateChain() actually says nothing
+	// about the order of the certificates in the chain. The sentence in this functions
+	// documentation is taken from QSslConfiguration::peerCertificateChain().
+	// Through tests and by looking into Qt's source code it was validated,
+	// that these two functions do the same thing.
+	// See mumble-voip/mumble#5280 for more information.
+	return qtsSocket->peerCertificateChain();
 }
 
 QSslCipher Connection::sessionCipher() const {
@@ -249,7 +254,7 @@ QString Connection::sessionProtocolString() const {
 #if QT_VERSION >= 0x050400
 	return MumbleSSL::protocolToString(sessionProtocol());
 #else
-	return QLatin1String("TLS"); // Cannot determine session cipher. We only know it's some TLS variant
+	return QLatin1String("TLS");  // Cannot determine session cipher. We only know it's some TLS variant
 #endif
 }
 
