@@ -1,17 +1,13 @@
-// Copyright 2005-2019 The Mumble Developers. All rights reserved.
+// Copyright 2017-2022 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
 
-#ifdef MUMBLE
-	#include "mumble_pch.hpp"
-#else
-	#include "murmur_pch.h"
-#endif
-
 #include "FFDHE.h"
 #include "FFDHETable.h"
 
+#include <QtCore/QStringList>
+
 QStringList FFDHE::NamedGroups() {
 	QStringList ng;
 	ng << QLatin1String("ffdhe2048");
