@@ -1,4 +1,4 @@
-// Copyright 2005-2019 The Mumble Developers. All rights reserved.
+// Copyright 2016-2022 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
@@ -10,14 +10,15 @@
 #include <QtCore/QString>
 
 class LogEmitter : public QObject {
-	private:
-		Q_OBJECT
-		Q_DISABLE_COPY(LogEmitter)
-	signals:
-		void newLogEntry(const QString &msg);
-	public:
-		LogEmitter(QObject *parent = NULL);
-		void addLogEntry(const QString &msg);
+private:
+	Q_OBJECT
+	Q_DISABLE_COPY(LogEmitter)
+signals:
+	void newLogEntry(const QString &msg);
+
+public:
+	LogEmitter(QObject *parent = nullptr);
+	void addLogEntry(const QString &msg);
 };
 
 #endif
