@@ -1,22 +1,15 @@
-// Copyright 2005-2019 The Mumble Developers. All rights reserved.
+// Copyright 2017-2022 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
 
-#ifdef MUMBLE
-	#include "mumble_pch.hpp"
-#else
-	#include "murmur_pch.h"
-#endif
-
 #include "ServerAddress.h"
 
-ServerAddress::ServerAddress()
-	: port(0) {}
+ServerAddress::ServerAddress() : port(0) {
+}
 
-ServerAddress::ServerAddress(HostAddress host_, unsigned short port_)
-	: host(host_)
-	, port(port_) {}
+ServerAddress::ServerAddress(HostAddress host_, unsigned short port_) : host(host_), port(port_) {
+}
 
 bool ServerAddress::isValid() const {
 	return host.isValid() && port != 0;
