@@ -1,35 +1,7 @@
-/* copyright (C) 2005-2011, Thorvald Natvig <thorvald@natvig.com>
-   Copyright (C) 2009-2011, Stefan Hacker <dd0t@users.sourceforge.net>
-
-   All rights reserved.
-
-   Redistribution and use in source and binary forms, with or without
-   modification, are permitted provided that the following conditions
-   are met:
-
-   - Redistributions of source code must retain the above copyright notice,
-     this list of conditions and the following disclaimer.
-   - Redistributions in binary form must reproduce the above copyright notice,
-     this list of conditions and the following disclaimer in the documentation
-     and/or other materials provided with the distribution.
-   - Neither the name of the Mumble Developers nor the names of its
-     contributors may be used to endorse or promote products derived from this
-     software without specific prior written permission.
-
-   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-   ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
-   A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR
-   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
-   EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
-   PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
-   PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
-   LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
-   NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
-   SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-*/
-
-#include "mumble_pch.hpp"
+// Copyright 2007-2022 The Mumble Developers. All rights reserved.
+// Use of this source code is governed by a BSD-style license
+// that can be found in the LICENSE file at the root of the
+// Mumble source tree or at <https://www.mumble.info/LICENSE>.
 
 #include "ACLEditor.h"
 
@@ -37,22 +9,46 @@
 #include "Channel.h"
 #include "ClientUser.h"
 #include "Database.h"
-#include "Global.h"
 #include "Log.h"
+#include "QtUtils.h"
 #include "ServerHandler.h"
 #include "User.h"
 
-ACLGroup::ACLGroup(const QString &name) : Group(NULL, name) {
+#if QT_VERSION >= 0x050000
+#	include <QtWidgets/QMessageBox>
+#else
+#	include <QtGui/QMessageBox>
+#endif
+
+#include "Global.h"
+
+ACLGroup::ACLGroup(const QString &name) : Group(nullptr, name) {
 	bInherited = false;
 }
 
 ACLEditor::ACLEditor(int channelparentid, QWidget *p) : QDialog(p) {
 	// Simple constructor for add channel menu
 	bAddChannelMode = true;
-	iChannel = channelparentid;
+	iChannel        = channelparentid;
 
 	setupUi(this);
 
+	qwChannel->setAccessibleName(tr("Properties"));
+	rteChannelDescription->setAccessibleName(tr("Description"));
+	qleChannelPassword->setAccessibleName(tr("Channel password"));
+	qsbChannelPosition->setAccessibleName(tr("Position"));
+	qsbChannelMaxUsers->setAccessibleName(tr("Maximum users"));
+	qleChannelName->setAccessibleName(tr("Channel name"));
+	qcbGroupList->setAccessibleName(tr("List of groups"));
+	qlwGroupAdd->setAccessibleName(tr("Inherited group members"));
+	qlwGroupRemove->setAccessibleName(tr("Foreign group members"));
+	qlwGroupInherit->setAccessibleName(tr("Inherited channel members"));
+	qcbGroupAdd->setAccessibleName(tr("Add members to group"));
+	qcbGroupRemove->setAccessibleName(tr("Remove member from group"));
+	qlwACLs->setAccessibleName(tr("List of ACL entries"));
+	qcbACLGroup->setAccessibleName(tr("Group this entry applies to"));
+	qcbACLUser->setAccessibleName(tr("User this entry applies to"));
+
 	qsbChannelPosition->setRange(INT_MIN, INT_MAX);
 
 	setWindowTitle(tr("Mumble - Add channel"));
@@ -63,9 +59,20 @@ ACLEditor::ACLEditor(int channelparentid, QWidget *p) : QDialog(p) {
 	qleChannelPassword->hide();
 	qlChannelPassword->hide();
 
+	if (Global::get().sh->m_version >= Version::fromComponents(1, 3, 0)) {
+		qsbChannelMaxUsers->setRange(0, INT_MAX);
+		qsbChannelMaxUsers->setValue(0);
+		qsbChannelMaxUsers->setSpecialValueText(tr("Default server value"));
+	} else {
+		qlChannelMaxUsers->hide();
+		qsbChannelMaxUsers->hide();
+	}
+
+	qlChannelID->hide();
+
 	qleChannelName->setFocus();
 
-	pcaPassword = NULL;
+	pcaPassword = nullptr;
 	adjustSize();
 }
 
@@ -74,10 +81,10 @@ ACLEditor::ACLEditor(int channelid, const MumbleProto::ACL &mea, QWidget *p) : Q
 
 	bAddChannelMode = false;
 
-	iChannel = channelid;
+	iChannel          = channelid;
 	Channel *pChannel = Channel::get(iChannel);
-	if (pChannel == NULL) {
-		g.l->log(Log::Warning, tr("Failed: Invalid channel"));
+	if (!pChannel) {
+		Global::get().l->log(Log::Warning, tr("Failed: Invalid channel"));
 		QDialog::reject();
 		return;
 	}
@@ -86,11 +93,29 @@ ACLEditor::ACLEditor(int channelid, const MumbleProto::ACL &mea, QWidget *p) : Q
 
 	setupUi(this);
 
+	qwChannel->setAccessibleName(tr("Properties"));
+	rteChannelDescription->setAccessibleName(tr("Description"));
+	qleChannelPassword->setAccessibleName(tr("Channel password"));
+	qsbChannelPosition->setAccessibleName(tr("Position"));
+	qsbChannelMaxUsers->setAccessibleName(tr("Maximum users"));
+	qleChannelName->setAccessibleName(tr("Channel name"));
+	qcbGroupList->setAccessibleName(tr("List of groups"));
+	qlwGroupAdd->setAccessibleName(tr("Inherited group members"));
+	qlwGroupRemove->setAccessibleName(tr("Foreign group members"));
+	qlwGroupInherit->setAccessibleName(tr("Inherited channel members"));
+	qcbGroupAdd->setAccessibleName(tr("Add members to group"));
+	qcbGroupRemove->setAccessibleName(tr("Remove member from group"));
+	qlwACLs->setAccessibleName(tr("List of ACL entries"));
+	qcbACLGroup->setAccessibleName(tr("Group this entry applies to"));
+	qcbACLUser->setAccessibleName(tr("User this entry applies to"));
+
 	qcbChannelTemporary->hide();
 
 	iId = mea.channel_id();
 	setWindowTitle(tr("Mumble - Edit %1").arg(Channel::get(iId)->qsName));
 
+	qlChannelID->setText(tr("ID: %1").arg(iId));
+
 	qleChannelName->setText(pChannel->qsName);
 	if (channelid == 0)
 		qleChannelName->setEnabled(false);
@@ -100,6 +125,15 @@ ACLEditor::ACLEditor(int channelid, const MumbleProto::ACL &mea, QWidget *p) : Q
 	qsbChannelPosition->setRange(INT_MIN, INT_MAX);
 	qsbChannelPosition->setValue(pChannel->iPosition);
 
+	if (Global::get().sh->m_version >= Version::fromComponents(1, 3, 0)) {
+		qsbChannelMaxUsers->setRange(0, INT_MAX);
+		qsbChannelMaxUsers->setValue(pChannel->uiMaxUsers);
+		qsbChannelMaxUsers->setSpecialValueText(tr("Default server value"));
+	} else {
+		qlChannelMaxUsers->hide();
+		qsbChannelMaxUsers->hide();
+	}
+
 	QGridLayout *grid = new QGridLayout(qgbACLpermissions);
 
 	l = new QLabel(tr("Deny"), qgbACLpermissions);
@@ -109,16 +143,26 @@ ACLEditor::ACLEditor(int channelid, const MumbleProto::ACL &mea, QWidget *p) : Q
 
 	int idx = 1;
 	for (int i = 0; i < ((iId == 0) ? 30 : 16); ++i) {
-		ChanACL::Perm perm = static_cast<ChanACL::Perm>(1 << i);
-		QString name = ChanACL::permName(perm);
+		ChanACL::Perm perm = static_cast< ChanACL::Perm >(1 << i);
+		QString name       = ChanACL::permName(perm);
+
+		if (!name.isEmpty()) {
+			// If the server's version is less than 1.4.0 then it won't support the new permissions.
+			// Skipping this iteration of the loop prevents checkboxes for it being added to the UI.
+			if (Global::get().sh->m_version < Version::fromComponents(1, 4, 0)
+				&& (perm == ChanACL::ResetUserContent || perm == ChanACL::Listen)) {
+				continue;
+			}
 
-		if (! name.isEmpty()) {
 			QCheckBox *qcb;
 			l = new QLabel(name, qgbACLpermissions);
 			grid->addWidget(l, idx, 0);
 			qcb = new QCheckBox(qgbACLpermissions);
 			qcb->setToolTip(tr("Deny %1").arg(name));
-			qcb->setWhatsThis(tr("This revokes the %1 privilege. If a privilege is both allowed and denied, it is denied.<br />%2").arg(name).arg(ChanACL::whatsThis(perm)));
+			qcb->setWhatsThis(
+				tr("This revokes the %1 privilege. If a privilege is both allowed and denied, it is denied.<br />%2")
+					.arg(name)
+					.arg(ChanACL::whatsThis(perm)));
 			connect(qcb, SIGNAL(clicked(bool)), this, SLOT(ACLPermissions_clicked()));
 			grid->addWidget(qcb, idx, 1);
 
@@ -126,7 +170,10 @@ ACLEditor::ACLEditor(int channelid, const MumbleProto::ACL &mea, QWidget *p) : Q
 
 			qcb = new QCheckBox(qgbACLpermissions);
 			qcb->setToolTip(tr("Allow %1").arg(name));
-			qcb->setWhatsThis(tr("This grants the %1 privilege. If a privilege is both allowed and denied, it is denied.<br />%2").arg(name).arg(ChanACL::whatsThis(perm)));
+			qcb->setWhatsThis(
+				tr("This grants the %1 privilege. If a privilege is both allowed and denied, it is denied.<br />%2")
+					.arg(name)
+					.arg(ChanACL::whatsThis(perm)));
 			connect(qcb, SIGNAL(clicked(bool)), this, SLOT(ACLPermissions_clicked()));
 			grid->addWidget(qcb, idx, 2);
 
@@ -143,21 +190,22 @@ ACLEditor::ACLEditor(int channelid, const MumbleProto::ACL &mea, QWidget *p) : Q
 	connect(qcbGroupAdd->lineEdit(), SIGNAL(returnPressed()), qpbGroupAddAdd, SLOT(animateClick()));
 	connect(qcbGroupRemove->lineEdit(), SIGNAL(returnPressed()), qpbGroupRemoveAdd, SLOT(animateClick()));
 
-	foreach(User *u, ClientUser::c_qmUsers) {
+	foreach (User *u, ClientUser::c_qmUsers) {
 		if (u->iId >= 0) {
 			qhNameCache.insert(u->iId, u->qsName);
 			qhIDCache.insert(u->qsName.toLower(), u->iId);
 		}
 	}
 
-	ChanACL *def = new ChanACL(NULL);
+	ChanACL *def = new ChanACL(nullptr);
 
 	def->bApplyHere = true;
 	def->bApplySubs = true;
 	def->bInherited = true;
-	def->iUserId = -1;
-	def->qsGroup = QLatin1String("all");
-	def->pAllow = ChanACL::Traverse | ChanACL::Enter | ChanACL::Speak | ChanACL::Whisper | ChanACL::TextMessage;
+	def->iUserId    = -1;
+	def->qsGroup    = QLatin1String("all");
+	def->pAllow =
+		ChanACL::Traverse | ChanACL::Enter | ChanACL::Speak | ChanACL::Whisper | ChanACL::TextMessage | ChanACL::Listen;
 	def->pDeny = (~def->pAllow) & ChanACL::All;
 
 	qlACLs << def;
@@ -165,17 +213,17 @@ ACLEditor::ACLEditor(int channelid, const MumbleProto::ACL &mea, QWidget *p) : Q
 	for (int i = 0; i < mea.acls_size(); ++i) {
 		const MumbleProto::ACL_ChanACL &as = mea.acls(i);
 
-		ChanACL *acl = new ChanACL(NULL);
+		ChanACL *acl    = new ChanACL(nullptr);
 		acl->bApplyHere = as.apply_here();
 		acl->bApplySubs = as.apply_subs();
 		acl->bInherited = as.inherited();
-		acl->iUserId = -1;
+		acl->iUserId    = -1;
 		if (as.has_user_id())
 			acl->iUserId = as.user_id();
 		else
 			acl->qsGroup = u8(as.group());
-		acl->pAllow = static_cast<ChanACL::Permissions>(as.grant());
-		acl->pDeny = static_cast<ChanACL::Permissions>(as.deny());
+		acl->pAllow = static_cast< ChanACL::Permissions >(as.grant());
+		acl->pDeny  = static_cast< ChanACL::Permissions >(as.deny());
 
 		qlACLs << acl;
 	}
@@ -183,9 +231,9 @@ ACLEditor::ACLEditor(int channelid, const MumbleProto::ACL &mea, QWidget *p) : Q
 	for (int i = 0; i < mea.groups_size(); ++i) {
 		const MumbleProto::ACL_ChanGroup &gs = mea.groups(i);
 
-		ACLGroup *gp = new ACLGroup(u8(gs.name()));
-		gp->bInherit = gs.inherit();
-		gp->bInherited = gs.inherited();
+		ACLGroup *gp     = new ACLGroup(u8(gs.name()));
+		gp->bInherit     = gs.inherit();
+		gp->bInherited   = gs.inherited();
 		gp->bInheritable = gs.inheritable();
 		for (int j = 0; j < gs.add_size(); ++j)
 			gp->qsAdd.insert(gs.add(j));
@@ -204,7 +252,7 @@ ACLEditor::ACLEditor(int channelid, const MumbleProto::ACL &mea, QWidget *p) : Q
 	bInheritACL = mea.inherit_acls();
 	qcbACLInherit->setChecked(bInheritACL);
 
-	foreach(ChanACL *acl, qlACLs) {
+	foreach (ChanACL *acl, qlACLs) {
 		if (acl->bInherited)
 			numInheritACL++;
 	}
@@ -225,12 +273,8 @@ ACLEditor::ACLEditor(int channelid, const MumbleProto::ACL &mea, QWidget *p) : Q
 }
 
 ACLEditor::~ACLEditor() {
-	foreach(ChanACL *acl, qlACLs) {
-		delete acl;
-	}
-	foreach(ACLGroup *gp, qlGroups) {
-		delete gp;
-	}
+	foreach (ChanACL *acl, qlACLs) { delete acl; }
+	foreach (ACLGroup *gp, qlGroups) { delete gp; }
 }
 
 void ACLEditor::showEvent(QShowEvent *evt) {
@@ -240,9 +284,9 @@ void ACLEditor::showEvent(QShowEvent *evt) {
 
 void ACLEditor::accept() {
 	Channel *pChannel = Channel::get(iChannel);
-	if (pChannel == NULL) {
+	if (!pChannel) {
 		// Channel gone while editing
-		g.l->log(Log::Warning, tr("Failed: Invalid channel"));
+		Global::get().l->log(Log::Warning, tr("Failed: Invalid channel"));
 		QDialog::reject();
 		return;
 	}
@@ -256,7 +300,9 @@ void ACLEditor::accept() {
 
 	// Update channel state
 	if (bAddChannelMode) {
-		g.sh->createChannel(iChannel, qleChannelName->text(), rteChannelDescription->text(), qsbChannelPosition->value(), qcbChannelTemporary->isChecked());
+		Global::get().sh->createChannel(iChannel, qleChannelName->text(), rteChannelDescription->text(),
+										qsbChannelPosition->value(), qcbChannelTemporary->isChecked(),
+										qsbChannelMaxUsers->value());
 	} else {
 		bool needs_update = false;
 
@@ -269,24 +315,28 @@ void ACLEditor::accept() {
 			needs_update = true;
 		}
 		if (rteChannelDescription->isModified() && (pChannel->qsDesc != rteChannelDescription->text())) {
-			const QString &msg = rteChannelDescription->text();
-			mpcs.set_description(u8(msg));
+			const QString &descriptionText = rteChannelDescription->text();
+			mpcs.set_description(u8(descriptionText));
 			needs_update = true;
-			Database::setBlob(sha1(msg), msg.toUtf8());
+			Global::get().db->setBlob(sha1(descriptionText), descriptionText.toUtf8());
 		}
 		if (pChannel->iPosition != qsbChannelPosition->value()) {
 			mpcs.set_position(qsbChannelPosition->value());
 			needs_update = true;
 		}
+		if (pChannel->uiMaxUsers != static_cast< unsigned int >(qsbChannelMaxUsers->value())) {
+			mpcs.set_max_users(qsbChannelMaxUsers->value());
+			needs_update = true;
+		}
 		if (needs_update)
-			g.sh->sendMessage(mpcs);
+			Global::get().sh->sendMessage(mpcs);
 
 		// Update ACL
 		msg.set_inherit_acls(bInheritACL);
 		msg.clear_acls();
 		msg.clear_groups();
 
-		foreach(ChanACL *acl, qlACLs) {
+		foreach (ChanACL *acl, qlACLs) {
 			if (acl->bInherited || (acl->iUserId < -1))
 				continue;
 			MumbleProto::ACL_ChanACL *mpa = msg.add_acls();
@@ -300,21 +350,22 @@ void ACLEditor::accept() {
 			mpa->set_deny(acl->pDeny);
 		}
 
-		foreach(ACLGroup *gp, qlGroups) {
-			if (gp->bInherited && gp->bInherit && gp->bInheritable && (gp->qsAdd.count() == 0) && (gp->qsRemove.count() == 0))
+		foreach (ACLGroup *gp, qlGroups) {
+			if (gp->bInherited && gp->bInherit && gp->bInheritable && (gp->qsAdd.count() == 0)
+				&& (gp->qsRemove.count() == 0))
 				continue;
 			MumbleProto::ACL_ChanGroup *mpg = msg.add_groups();
 			mpg->set_name(u8(gp->qsName));
 			mpg->set_inherit(gp->bInherit);
 			mpg->set_inheritable(gp->bInheritable);
-			foreach(int pid, gp->qsAdd)
+			foreach (int pid, gp->qsAdd)
 				if (pid >= 0)
 					mpg->add_add(pid);
-			foreach(int pid, gp->qsRemove)
+			foreach (int pid, gp->qsRemove)
 				if (pid >= 0)
 					mpg->add_remove(pid);
 		}
-		g.sh->sendMessage(msg);
+		Global::get().sh->sendMessage(msg);
 	}
 	QDialog::accept();
 }
@@ -332,10 +383,10 @@ int ACLEditor::id(const QString &uname) {
 	if (qhIDCache.contains(name)) {
 		return qhIDCache.value(name);
 	} else {
-		if (! qhNameWait.contains(name)) {
+		if (!qhNameWait.contains(name)) {
 			MumbleProto::QueryUsers mpuq;
 			mpuq.add_names(u8(name));
-			g.sh->sendMessage(mpuq);
+			Global::get().sh->sendMessage(mpuq);
 
 			iUnknown--;
 			qhNameWait.insert(name, iUnknown);
@@ -350,8 +401,8 @@ void ACLEditor::returnQuery(const MumbleProto::QueryUsers &mqu) {
 		return;
 
 	for (int i = 0; i < mqu.names_size(); ++i) {
-		int pid = mqu.ids(i);
-		QString name = u8(mqu.names(i));
+		int pid       = mqu.ids(i);
+		QString name  = u8(mqu.names(i));
 		QString lname = name.toLower();
 		qhIDCache.insert(lname, pid);
 		qhNameCache.insert(pid, name);
@@ -359,10 +410,10 @@ void ACLEditor::returnQuery(const MumbleProto::QueryUsers &mqu) {
 		if (qhNameWait.contains(lname)) {
 			int tid = qhNameWait.take(lname);
 
-			foreach(ChanACL *acl, qlACLs)
+			foreach (ChanACL *acl, qlACLs)
 				if (acl->iUserId == tid)
 					acl->iUserId = pid;
-			foreach(ACLGroup *gp, qlGroups) {
+			foreach (ACLGroup *gp, qlGroups) {
 				if (gp->qsAdd.remove(tid))
 					gp->qsAdd.insert(pid);
 				if (gp->qsRemove.remove(tid))
@@ -396,7 +447,7 @@ void ACLEditor::refill(WaitID wid) {
 }
 
 void ACLEditor::refillComboBoxes() {
-	QList<QComboBox *> ql;
+	QList< QComboBox * > ql;
 	ql << qcbGroupAdd;
 	ql << qcbGroupRemove;
 	ql << qcbACLUser;
@@ -404,7 +455,7 @@ void ACLEditor::refillComboBoxes() {
 	QStringList names = qhNameCache.values();
 	names.sort();
 
-	foreach(QComboBox *qcb, ql) {
+	foreach (QComboBox *qcb, ql) {
 		qcb->clear();
 		qcb->addItems(names);
 		qcb->clearEditText();
@@ -412,18 +463,18 @@ void ACLEditor::refillComboBoxes() {
 }
 
 void ACLEditor::refillACL() {
-	int idx = qlwACLs->currentRow();
+	int idx              = qlwACLs->currentRow();
 	bool previousinherit = bInheritACL;
-	bInheritACL = qcbACLInherit->isChecked();
+	bInheritACL          = qcbACLInherit->isChecked();
 
 	qlwACLs->clear();
 
 	bool first = true;
 
-	foreach(ChanACL *acl, qlACLs) {
+	foreach (ChanACL *acl, qlACLs) {
 		if (first)
 			first = false;
-		else if (! bInheritACL && acl->bInherited)
+		else if (!bInheritACL && acl->bInherited)
 			continue;
 		QString text;
 		if (acl->iUserId == -1)
@@ -437,9 +488,9 @@ void ACLEditor::refillACL() {
 			item->setFont(f);
 		}
 	}
-	if (bInheritACL && ! previousinherit && (idx != 0))
+	if (bInheritACL && !previousinherit && (idx != 0))
 		idx += numInheritACL;
-	if (! bInheritACL && previousinherit)
+	if (!bInheritACL && previousinherit)
 		idx -= numInheritACL;
 
 	qlwACLs->setCurrentRow(idx);
@@ -449,16 +500,12 @@ void ACLEditor::refillGroupNames() {
 	QString text = qcbGroupList->currentText().toLower();
 	QStringList qsl;
 
-	foreach(ACLGroup *gp, qlGroups) {
-		qsl << gp->qsName;
-	}
+	foreach (ACLGroup *gp, qlGroups) { qsl << gp->qsName; }
 	qsl.sort();
 
 	qcbGroupList->clear();
 
-	foreach(QString name, qsl) {
-		qcbGroupList->addItem(name);
-	}
+	foreach (QString name, qsl) { qcbGroupList->addItem(name); }
 
 	int wantindex = qcbGroupList->findText(text, Qt::MatchFixedString);
 	qcbGroupList->setCurrentIndex(wantindex);
@@ -467,38 +514,36 @@ void ACLEditor::refillGroupNames() {
 ACLGroup *ACLEditor::currentGroup() {
 	QString group = qcbGroupList->currentText();
 
-	foreach(ACLGroup *gp, qlGroups)
+	foreach (ACLGroup *gp, qlGroups)
 		if (gp->qsName == group)
 			return gp;
 
 	group = group.toLower();
 
-	foreach(ACLGroup *gp, qlGroups)
+	foreach (ACLGroup *gp, qlGroups)
 		if (gp->qsName == group)
 			return gp;
 
-	return NULL;
+	return nullptr;
 }
 
 ChanACL *ACLEditor::currentACL() {
 	int idx = qlwACLs->currentRow();
 	if (idx < 0)
-		return NULL;
+		return nullptr;
 
-	if (idx && ! bInheritACL)
+	if (idx && !bInheritACL)
 		idx += numInheritACL;
 	return qlACLs[idx];
 }
 
-void ACLEditor::fillWidgetFromSet(QListWidget *qlw, const QSet<int> &qs) {
+void ACLEditor::fillWidgetFromSet(QListWidget *qlw, const QSet< int > &qs) {
 	qlw->clear();
 
-	QList<idname> ql;
-	foreach(int pid, qs) {
-		ql << idname(userName(pid), pid);
-	}
-	qStableSort(ql);
-	foreach(idname i, ql) {
+	QList< idname > ql;
+	foreach (int pid, qs) { ql << idname(userName(pid), pid); }
+	std::stable_sort(ql.begin(), ql.end());
+	foreach (idname i, ql) {
 		QListWidgetItem *qlwi = new QListWidgetItem(i.first, qlw);
 		qlwi->setData(Qt::UserRole, i.second);
 		if (i.second < 0) {
@@ -512,7 +557,7 @@ void ACLEditor::fillWidgetFromSet(QListWidget *qlw, const QSet<int> &qs) {
 void ACLEditor::refillGroupAdd() {
 	ACLGroup *gp = currentGroup();
 
-	if (! gp)
+	if (!gp)
 		return;
 
 	fillWidgetFromSet(qlwGroupAdd, gp->qsAdd);
@@ -520,7 +565,7 @@ void ACLEditor::refillGroupAdd() {
 
 void ACLEditor::refillGroupRemove() {
 	ACLGroup *gp = currentGroup();
-	if (! gp)
+	if (!gp)
 		return;
 
 	fillWidgetFromSet(qlwGroupRemove, gp->qsRemove);
@@ -529,7 +574,7 @@ void ACLEditor::refillGroupRemove() {
 void ACLEditor::refillGroupInherit() {
 	ACLGroup *gp = currentGroup();
 
-	if (! gp)
+	if (!gp)
 		return;
 
 	fillWidgetFromSet(qlwGroupInherit, gp->qsTemporary);
@@ -539,7 +584,7 @@ void ACLEditor::groupEnableCheck() {
 	ACLGroup *gp = currentGroup();
 
 	bool enabled;
-	if (! gp)
+	if (!gp)
 		enabled = false;
 	else
 		enabled = gp->bInherit;
@@ -551,7 +596,7 @@ void ACLEditor::groupEnableCheck() {
 	qpbGroupRemoveRemove->setEnabled(enabled);
 	qpbGroupInheritRemove->setEnabled(enabled);
 
-	enabled = (gp != NULL);
+	enabled = gp;
 	qlwGroupAdd->setEnabled(enabled);
 	qcbGroupAdd->setEnabled(enabled);
 	qpbGroupAddAdd->setEnabled(enabled);
@@ -570,10 +615,10 @@ void ACLEditor::ACLEnableCheck() {
 	ChanACL *as = currentACL();
 
 	bool enabled;
-	if (! as)
+	if (!as)
 		enabled = false;
 	else
-		enabled = ! as->bInherited;
+		enabled = !as->bInherited;
 
 	qpbACLRemove->setEnabled(enabled);
 	qpbACLUp->setEnabled(enabled);
@@ -585,7 +630,9 @@ void ACLEditor::ACLEnableCheck() {
 
 	for (int idx = 0; idx < qlACLAllow.count(); idx++) {
 		// Only enable other checkboxes if writeacl isn't set
-		bool enablethis = enabled && (qlPerms[idx] == ChanACL::Write || !(as && (as->pAllow & ChanACL::Write)) || qlPerms[idx] == ChanACL::Speak);
+		bool enablethis = enabled
+						  && (qlPerms[idx] == ChanACL::Write || !(as && (as->pAllow & ChanACL::Write))
+							  || qlPerms[idx] == ChanACL::Speak);
 		qlACLAllow[idx]->setEnabled(enablethis);
 		qlACLDeny[idx]->setEnabled(enablethis);
 	}
@@ -611,7 +658,7 @@ void ACLEditor::ACLEnableCheck() {
 		qcbACLGroup->addItem(QLatin1String("~sub"));
 		qcbACLGroup->addItem(QLatin1String("~out"));
 
-		foreach(ACLGroup *gs, qlGroups)
+		foreach (ACLGroup *gs, qlGroups)
 			qcbACLGroup->addItem(gs->qsName);
 
 		if (as->iUserId == -1) {
@@ -622,8 +669,8 @@ void ACLEditor::ACLEnableCheck() {
 			qcbACLUser->setEditText(userName(as->iUserId));
 		}
 	}
-	foreach(QAbstractButton *b, qdbbButtons->buttons()) {
-		QPushButton *qpb = qobject_cast<QPushButton *>(b);
+	foreach (QAbstractButton *b, qdbbButtons->buttons()) {
+		QPushButton *qpb = qobject_cast< QPushButton * >(b);
 		if (qpb) {
 			qpb->setAutoDefault(false);
 			qpb->setDefault(false);
@@ -643,17 +690,10 @@ void ACLEditor::on_qtwTab_currentChanged(int index) {
 }
 
 void ACLEditor::updatePasswordField() {
-	pcaPassword = NULL;
-	foreach(ChanACL *acl, qlACLs) {
-		// Check for sth that applies to '#<something>' AND grants 'Enter' AND may grant 'Speak', 'Whisper',
-		// 'TextMessage', 'Link' but NOTHING else AND does not deny anything, then '<something>' is the password.
-		if (acl->qsGroup.startsWith(QLatin1Char('#')) &&
-		        acl->bApplyHere &&
-		        !acl->bInherited &&
-		        (acl->pAllow & ChanACL::Enter) &&
-		        (acl->pAllow == (ChanACL::Enter | ChanACL::Speak | ChanACL::Whisper | ChanACL::TextMessage | ChanACL::LinkChannel) || // Backwards compat with old behaviour that didn't deny traverse
-		         acl->pAllow == (ChanACL::Enter | ChanACL::Speak | ChanACL::Whisper | ChanACL::TextMessage | ChanACL::LinkChannel | ChanACL::Traverse)) &&
-		        acl->pDeny == ChanACL::None) {
+	// Search for an ACL that represents the current password
+	pcaPassword = nullptr;
+	foreach (ChanACL *acl, qlACLs) {
+		if (acl->isPassword()) {
 			pcaPassword = acl;
 		}
 	}
@@ -661,7 +701,6 @@ void ACLEditor::updatePasswordField() {
 		qleChannelPassword->setText(pcaPassword->qsGroup.mid(1));
 	else
 		qleChannelPassword->clear();
-
 }
 
 void ACLEditor::updatePasswordACL() {
@@ -671,14 +710,17 @@ void ACLEditor::updatePasswordACL() {
 			delete pcaPassword;
 
 			// Search and remove the @all deny ACL
-			ChanACL *denyall = NULL;
-			foreach(ChanACL *acl, qlACLs) {
-				if (acl->qsGroup == QLatin1String("all") &&
-				        acl->bInherited == false &&
-				        acl->bApplyHere == true &&
-				        acl->pAllow == ChanACL::None &&
-				        (acl->pDeny == (ChanACL::Enter | ChanACL::Speak | ChanACL::Whisper | ChanACL::TextMessage | ChanACL::LinkChannel) || // Backwards compat with old behaviour that didn't deny traverse
-				         acl->pDeny == (ChanACL::Enter | ChanACL::Speak | ChanACL::Whisper | ChanACL::TextMessage | ChanACL::LinkChannel | ChanACL::Traverse))) {
+			ChanACL *denyall = nullptr;
+			foreach (ChanACL *acl, qlACLs) {
+				if (acl->qsGroup == QLatin1String("all") && acl->bInherited == false && acl->bApplyHere == true
+					&& acl->pAllow == ChanACL::None
+					&& (acl->pDeny
+							== (ChanACL::Enter | ChanACL::Speak | ChanACL::Whisper | ChanACL::TextMessage
+								| ChanACL::LinkChannel)
+						|| // Backwards compat with old behaviour that didn't deny traverse
+						acl->pDeny
+							== (ChanACL::Enter | ChanACL::Speak | ChanACL::Whisper | ChanACL::TextMessage
+								| ChanACL::LinkChannel | ChanACL::Traverse))) {
 					denyall = acl;
 				}
 			}
@@ -689,22 +731,24 @@ void ACLEditor::updatePasswordACL() {
 		}
 	} else {
 		// Add or Update
-		if (pcaPassword == NULL || !qlACLs.contains(pcaPassword)) {
-			pcaPassword = new ChanACL(NULL);
+		if (!pcaPassword || !qlACLs.contains(pcaPassword)) {
+			pcaPassword             = new ChanACL(nullptr);
 			pcaPassword->bApplyHere = true;
 			pcaPassword->bApplySubs = false;
 			pcaPassword->bInherited = false;
-			pcaPassword->pAllow = ChanACL::None;
-			pcaPassword->pDeny = ChanACL::Enter | ChanACL::Speak | ChanACL::Whisper | ChanACL::TextMessage | ChanACL::LinkChannel | ChanACL::Traverse;
+			pcaPassword->pAllow     = ChanACL::None;
+			pcaPassword->pDeny      = ChanACL::Enter | ChanACL::Speak | ChanACL::Whisper | ChanACL::TextMessage
+								 | ChanACL::LinkChannel | ChanACL::Traverse;
 			pcaPassword->qsGroup = QLatin1String("all");
 			qlACLs << pcaPassword;
 
-			pcaPassword = new ChanACL(NULL);
+			pcaPassword             = new ChanACL(nullptr);
 			pcaPassword->bApplyHere = true;
 			pcaPassword->bApplySubs = false;
 			pcaPassword->bInherited = false;
-			pcaPassword->pAllow = ChanACL::Enter | ChanACL::Speak | ChanACL::Whisper | ChanACL::TextMessage | ChanACL::LinkChannel | ChanACL::Traverse;
-			pcaPassword->pDeny = ChanACL::None;
+			pcaPassword->pAllow     = ChanACL::Enter | ChanACL::Speak | ChanACL::Whisper | ChanACL::TextMessage
+								  | ChanACL::LinkChannel | ChanACL::Traverse;
+			pcaPassword->pDeny   = ChanACL::None;
 			pcaPassword->qsGroup = QString(QLatin1String("#%1")).arg(qleChannelPassword->text());
 			qlACLs << pcaPassword;
 		} else {
@@ -718,14 +762,14 @@ void ACLEditor::on_qlwACLs_currentRowChanged() {
 }
 
 void ACLEditor::on_qpbACLAdd_clicked() {
-	ChanACL *as = new ChanACL(NULL);
+	ChanACL *as    = new ChanACL(nullptr);
 	as->bApplyHere = true;
 	as->bApplySubs = true;
 	as->bInherited = false;
-	as->qsGroup = QLatin1String("all");
-	as->iUserId = -1;
-	as->pAllow = ChanACL::None;
-	as->pDeny = ChanACL::None;
+	as->qsGroup    = QLatin1String("all");
+	as->iUserId    = -1;
+	as->pAllow     = ChanACL::None;
+	as->pDeny      = ChanACL::None;
 	qlACLs << as;
 	refillACL();
 	qlwACLs->setCurrentRow(qlwACLs->count() - 1);
@@ -733,7 +777,7 @@ void ACLEditor::on_qpbACLAdd_clicked() {
 
 void ACLEditor::on_qpbACLRemove_clicked() {
 	ChanACL *as = currentACL();
-	if (! as || as->bInherited)
+	if (!as || as->bInherited)
 		return;
 
 	qlACLs.removeAll(as);
@@ -743,28 +787,36 @@ void ACLEditor::on_qpbACLRemove_clicked() {
 
 void ACLEditor::on_qpbACLUp_clicked() {
 	ChanACL *as = currentACL();
-	if (! as || as->bInherited)
+	if (!as || as->bInherited)
 		return;
 
 	int idx = qlACLs.indexOf(as);
 	if (idx <= numInheritACL + 1)
 		return;
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+	qlACLs.swapItemsAt(idx - 1, idx);
+#else
 	qlACLs.swap(idx - 1, idx);
+#endif
 	qlwACLs->setCurrentRow(qlwACLs->currentRow() - 1);
 	refillACL();
 }
 
 void ACLEditor::on_qpbACLDown_clicked() {
 	ChanACL *as = currentACL();
-	if (! as || as->bInherited)
+	if (!as || as->bInherited)
 		return;
 
 	int idx = qlACLs.indexOf(as) + 1;
 	if (idx >= qlACLs.count())
 		return;
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
+	qlACLs.swapItemsAt(idx - 1, idx);
+#else
 	qlACLs.swap(idx - 1, idx);
+#endif
 	qlwACLs->setCurrentRow(qlwACLs->currentRow() + 1);
 	refillACL();
 }
@@ -775,7 +827,7 @@ void ACLEditor::on_qcbACLInherit_clicked(bool) {
 
 void ACLEditor::on_qcbACLApplyHere_clicked(bool checked) {
 	ChanACL *as = currentACL();
-	if (! as || as->bInherited)
+	if (!as || as->bInherited)
 		return;
 
 	as->bApplyHere = checked;
@@ -783,7 +835,7 @@ void ACLEditor::on_qcbACLApplyHere_clicked(bool checked) {
 
 void ACLEditor::on_qcbACLApplySubs_clicked(bool checked) {
 	ChanACL *as = currentACL();
-	if (! as || as->bInherited)
+	if (!as || as->bInherited)
 		return;
 
 	as->bApplySubs = checked;
@@ -791,7 +843,7 @@ void ACLEditor::on_qcbACLApplySubs_clicked(bool checked) {
 
 void ACLEditor::on_qcbACLGroup_activated(const QString &text) {
 	ChanACL *as = currentACL();
-	if (! as || as->bInherited)
+	if (!as || as->bInherited)
 		return;
 
 	as->iUserId = -1;
@@ -810,7 +862,7 @@ void ACLEditor::on_qcbACLUser_activated() {
 	QString text = qcbACLUser->currentText();
 
 	ChanACL *as = currentACL();
-	if (! as || as->bInherited)
+	if (!as || as->bInherited)
 		return;
 
 	if (text.isEmpty()) {
@@ -828,16 +880,17 @@ void ACLEditor::on_qcbACLUser_activated() {
 }
 
 void ACLEditor::ACLPermissions_clicked() {
-	QCheckBox *source = qobject_cast<QCheckBox *>(sender());
+	QCheckBox *source = qobject_cast< QCheckBox * >(sender());
 
 	ChanACL *as = currentACL();
-	if (! as || as->bInherited)
+	if (!as || as->bInherited)
 		return;
 
 	int allowed = 0;
-	int denied = 0;
+	int denied  = 0;
 
-	bool enabled = true;
+	bool enabled       = true;
+	bool modifiedEnter = false;
 	for (int idx = 0; idx < qlACLAllow.count(); idx++) {
 		ChanACL::Perm p = qlPerms[idx];
 		if (qlACLAllow[idx]->isChecked() && qlACLDeny[idx]->isChecked()) {
@@ -847,6 +900,31 @@ void ACLEditor::ACLPermissions_clicked() {
 				qlACLAllow[idx]->setChecked(false);
 		}
 
+		if (p == ChanACL::Enter && (source == qlACLAllow[idx] || source == qlACLDeny[idx])) {
+			// Unchecking a checkbox is not counted as modifying the Enter privilege
+			// in this context
+			modifiedEnter = source->isChecked();
+		}
+
+		if (p == ChanACL::Listen && modifiedEnter) {
+			// If Enter privileges are granted, also grant Listen privilege
+			// and vice versa.
+			// This is to make sure that people don't accidentally forget to
+			// modify the Listen permission when they modify the enter permission.
+			// Especially in the case of denying enter, this could potentially lead
+			// to confusion if people were still able to listen to a channel they can't
+			// enter.
+			// However the user still can allow/deny the Listen permission manually after
+			// having changed the enter permission.
+			if (denied & ChanACL::Enter) {
+				qlACLAllow[idx]->setChecked(false);
+				qlACLDeny[idx]->setChecked(true);
+			} else {
+				qlACLAllow[idx]->setChecked(true);
+				qlACLDeny[idx]->setChecked(false);
+			}
+		}
+
 		qlACLAllow[idx]->setEnabled(enabled || p == ChanACL::Speak);
 		qlACLDeny[idx]->setEnabled(enabled || p == ChanACL::Speak);
 
@@ -859,21 +937,21 @@ void ACLEditor::ACLPermissions_clicked() {
 			denied |= p;
 	}
 
-	as->pAllow = static_cast<ChanACL::Permissions>(allowed);
-	as->pDeny = static_cast<ChanACL::Permissions>(denied);
+	as->pAllow = static_cast< ChanACL::Permissions >(allowed);
+	as->pDeny  = static_cast< ChanACL::Permissions >(denied);
 }
 
 void ACLEditor::on_qcbGroupList_activated(const QString &text) {
 	ACLGroup *gs = currentGroup();
 	if (text.isEmpty())
 		return;
-	if (! gs) {
-		QString name = text.toLower();
-		gs = new ACLGroup(name);
-		gs->bInherited = false;
-		gs->bInherit = true;
+	if (!gs) {
+		QString name     = text.toLower();
+		gs               = new ACLGroup(name);
+		gs->bInherited   = false;
+		gs->bInherit     = true;
 		gs->bInheritable = true;
-		gs->qsName = name;
+		gs->qsName       = name;
 		qlGroups << gs;
 	}
 
@@ -885,7 +963,7 @@ void ACLEditor::on_qcbGroupList_activated(const QString &text) {
 	qpbGroupAdd->setEnabled(false);
 }
 
-void ACLEditor::on_qcbGroupList_editTextChanged(const QString & text) {
+void ACLEditor::on_qcbGroupList_editTextChanged(const QString &text) {
 	qpbGroupAdd->setEnabled(!text.isEmpty());
 }
 
@@ -895,12 +973,12 @@ void ACLEditor::on_qpbGroupAdd_clicked() {
 
 void ACLEditor::on_qpbGroupRemove_clicked() {
 	ACLGroup *gs = currentGroup();
-	if (! gs)
+	if (!gs)
 		return;
 
 	if (gs->bInherited) {
 		gs->bInheritable = true;
-		gs->bInherit = true;
+		gs->bInherit     = true;
 		gs->qsAdd.clear();
 		gs->qsRemove.clear();
 	} else {
@@ -916,7 +994,7 @@ void ACLEditor::on_qpbGroupRemove_clicked() {
 
 void ACLEditor::on_qcbGroupInherit_clicked(bool checked) {
 	ACLGroup *gs = currentGroup();
-	if (! gs)
+	if (!gs)
 		return;
 
 	gs->bInherit = checked;
@@ -925,7 +1003,7 @@ void ACLEditor::on_qcbGroupInherit_clicked(bool checked) {
 
 void ACLEditor::on_qcbGroupInheritable_clicked(bool checked) {
 	ACLGroup *gs = currentGroup();
-	if (! gs)
+	if (!gs)
 		return;
 
 	gs->bInheritable = checked;
@@ -935,7 +1013,7 @@ void ACLEditor::on_qpbGroupAddAdd_clicked() {
 	ACLGroup *gs = currentGroup();
 	QString text = qcbGroupAdd->currentText();
 
-	if (! gs)
+	if (!gs)
 		return;
 
 	if (text.isEmpty())
@@ -948,11 +1026,11 @@ void ACLEditor::on_qpbGroupAddAdd_clicked() {
 
 void ACLEditor::on_qpbGroupAddRemove_clicked() {
 	ACLGroup *gs = currentGroup();
-	if (! gs)
+	if (!gs)
 		return;
 
 	QListWidgetItem *item = qlwGroupAdd->currentItem();
-	if (! item)
+	if (!item)
 		return;
 
 	gs->qsAdd.remove(item->data(Qt::UserRole).toInt());
@@ -964,7 +1042,7 @@ void ACLEditor::on_qpbGroupRemoveAdd_clicked() {
 	QString text = qcbGroupRemove->currentText();
 
 	ACLGroup *gs = currentGroup();
-	if (! gs)
+	if (!gs)
 		return;
 
 	if (text.isEmpty())
@@ -976,11 +1054,11 @@ void ACLEditor::on_qpbGroupRemoveAdd_clicked() {
 
 void ACLEditor::on_qpbGroupRemoveRemove_clicked() {
 	ACLGroup *gs = currentGroup();
-	if (! gs)
+	if (!gs)
 		return;
 
 	QListWidgetItem *item = qlwGroupRemove->currentItem();
-	if (! item)
+	if (!item)
 		return;
 
 	gs->qsRemove.remove(item->data(Qt::UserRole).toInt());
@@ -989,11 +1067,11 @@ void ACLEditor::on_qpbGroupRemoveRemove_clicked() {
 
 void ACLEditor::on_qpbGroupInheritRemove_clicked() {
 	ACLGroup *gs = currentGroup();
-	if (! gs)
+	if (!gs)
 		return;
 
 	QListWidgetItem *item = qlwGroupInherit->currentItem();
-	if (! item)
+	if (!item)
 		return;
 
 	gs->qsRemove.insert(item->data(Qt::UserRole).toInt());
