@@ -1,4 +1,4 @@
-// Copyright 2005-2019 The Mumble Developers. All rights reserved.
+// Copyright 2007-2022 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
@@ -6,20 +6,16 @@
 #ifndef MUMBLE_MUMBLE_ABOUT_H_
 #define MUMBLE_MUMBLE_ABOUT_H_
 
-#include <QtCore/QtGlobal>
 #include <QtCore/QObject>
-#if QT_VERSION >= 0x050000
-# include <QtWidgets/QDialog>
-#else
-# include <QtGui/QDialog>
-#endif
+#include <QtCore/QtGlobal>
+#include <QtWidgets/QDialog>
 
 class AboutDialog : public QDialog {
-	private:
-		Q_OBJECT
-		Q_DISABLE_COPY(AboutDialog)
-	public:
-		AboutDialog(QWidget *parent);
+private:
+	Q_OBJECT
+	Q_DISABLE_COPY(AboutDialog)
+public:
+	AboutDialog(QWidget *parent);
 };
 
 #endif
