@@ -1,19 +1,17 @@
-// Copyright 2005-2019 The Mumble Developers. All rights reserved.
+// Copyright 2016-2022 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
 
-#include "mumble_pch.hpp"
-
 #include "DeveloperConsole.h"
 
 #include "LogEmitter.h"
 #include "Global.h"
 
-DeveloperConsole::DeveloperConsole(QObject *parent)
-	: QObject(parent)  {
+#include <QtWidgets/QTextBrowser>
 
-	connect(g.le.data(), SIGNAL(newLogEntry(const QString &)), this, SLOT(addLogMessage(const QString &)));
+DeveloperConsole::DeveloperConsole(QObject *parent) : QObject(parent) {
+	connect(Global::get().le.data(), SIGNAL(newLogEntry(const QString &)), this, SLOT(addLogMessage(const QString &)));
 }
 
 DeveloperConsole::~DeveloperConsole() {
@@ -30,11 +28,11 @@ void DeveloperConsole::show() {
 		mw->setCentralWidget(tb);
 		mw->setWindowTitle(tr("Developer Console"));
 
-		connect(g.le.data(), SIGNAL(newLogEntry(const QString &)), tb, SLOT(append(const QString &)));
+		connect(Global::get().le.data(), SIGNAL(newLogEntry(const QString &)), tb, SLOT(append(const QString &)));
 
-		foreach(const QString &m, m_logEntries)
+		foreach (const QString &m, m_logEntries)
 			tb->append(m);
-		m_window = QPointer<QMainWindow>(mw);
+		m_window = QPointer< QMainWindow >(mw);
 	}
 
 	m_window.data()->show();
