@@ -1,4 +1,4 @@
-// Copyright 2005-2019 The Mumble Developers. All rights reserved.
+// Copyright 2007-2022 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
@@ -6,14 +6,17 @@
 #ifndef MUMBLE_MUMBLE_GLOBAL_H_
 #define MUMBLE_MUMBLE_GLOBAL_H_
 
-#include <boost/shared_ptr.hpp>
 #include <QtCore/QDir>
+#include <boost/shared_ptr.hpp>
 
 #include "ACL.h"
+#include "ChannelListenerManager.h"
 #include "Settings.h"
 #include "Timer.h"
 #include "Version.h"
 
+#include <memory>
+
 // Global helper class to spread variables around across threads.
 
 class MainWindow;
@@ -22,42 +25,51 @@ class AudioInput;
 class AudioOutput;
 class Database;
 class Log;
-class Plugins;
+class PluginManager;
 class QSettings;
 class Overlay;
 class LCD;
-class BonjourClient;
+class Zeroconf;
 class OverlayClient;
-class CELTCodec;
-class OpusCodec;
 class LogEmitter;
 class DeveloperConsole;
+class TalkingUI;
 
 class QNetworkAccessManager;
 
+struct MigratedPath {
+	QString oldPath;
+	QString newPath;
+};
+
 struct Global Q_DECL_FINAL {
 private:
 	Q_DISABLE_COPY(Global)
 public:
 	static Global *g_global_struct;
+	static Global &get();
+
 	MainWindow *mw;
 	Settings s;
-	boost::shared_ptr<ServerHandler> sh;
-	boost::shared_ptr<AudioInput> ai;
-	boost::shared_ptr<AudioOutput> ao;
+	boost::shared_ptr< ServerHandler > sh;
+	boost::shared_ptr< AudioInput > ai;
+	boost::shared_ptr< AudioOutput > ao;
 	/**
 	 * @remark Must only be accessed from the main event loop
 	 */
 	Database *db;
 	Log *l;
-	Plugins *p;
-	QSettings *qs;
+	/// A pointer to the PluginManager that is used in this session
+	PluginManager *pluginManager;
+#ifdef USE_OVERLAY
 	Overlay *o;
+#endif
 	LCD *lcd;
-	BonjourClient *bc;
+	Zeroconf *zeroconf;
 	QNetworkAccessManager *nam;
-	QSharedPointer<LogEmitter> le;
+	QSharedPointer< LogEmitter > le;
 	DeveloperConsole *c;
+	TalkingUI *talkingUI;
 	int iPushToTalk;
 	Timer tDoublePush;
 	quint64 uiDoublePush;
@@ -71,18 +83,18 @@ public:
 	bool bCenterPosition;
 	bool bPosTest;
 	bool bInAudioWizard;
+#ifdef USE_OVERLAY
 	OverlayClient *ocIntercept;
+#endif
 	int iAudioPathTime;
+	/// A unique ID for the current user. It is being assigned by the server right
+	/// after connecting to it. An ID of 0 indicates that the user currently isn't
+	/// connected to a server.
 	unsigned int uiSession;
 	ChanACL::Permissions pPermissions;
 	int iMaxBandwidth;
 	int iAudioBandwidth;
 	QDir qdBasePath;
-	QMap<int, CELTCodec *> qmCodecs;
-	OpusCodec *oCodec;
-	int iCodecAlpha, iCodecBeta;
-	bool bPreferAlpha;
-	bool bOpus;
 	bool bAttenuateOthers;
 	/// If set the AudioOutput::mix will forcefully adjust the volume of all
 	/// non-priority speakers.
@@ -91,13 +103,24 @@ public:
 	unsigned int uiMessageLength;
 	unsigned int uiImageLength;
 	unsigned int uiMaxUsers;
+	bool recordingAllowed;
 	bool bQuit;
+	QString windowTitlePostfix;
+	bool bDebugDumpInput;
+	bool bDebugPrintQueue;
+	std::unique_ptr< ChannelListenerManager > channelListenerManager;
 
 	bool bHappyEaster;
 	static const char ccHappyEaster[];
 
-	Global();
-	~Global();
+	QString migratedDBPath;
+	MigratedPath migratedPluginDirPath;
+
+	Global(const QString &qsConfigPath = QString());
+	~Global() = default;
+
+private:
+	void migrateDataDir(const QDir &toDir);
 };
 
 // Class to handle ordered initialization of globals.
@@ -106,32 +129,23 @@ public:
 // after we reach main().
 
 class DeferInit {
-	private:
-		Q_DISABLE_COPY(DeferInit)
-	protected:
-		static QMultiMap<int, DeferInit *> *qmDeferers;
-		void add(int priority);
-	public:
-		DeferInit(int priority) {
-			add(priority);
-		};
-		DeferInit() {
-			add(0);
-		};
-		virtual ~DeferInit();
-		virtual void initialize() { };
-		virtual void destroy() { };
-		static void run_initializers();
-		static void run_destroyers();
+private:
+	Q_DISABLE_COPY(DeferInit)
+protected:
+	static QMultiMap< int, DeferInit * > *qmDeferers;
+	void add(int priority);
+
+public:
+	DeferInit(int priority) { add(priority); };
+	DeferInit() { add(0); };
+	virtual ~DeferInit();
+	virtual void initialize(){};
+	virtual void destroy(){};
+	static void run_initializers();
+	static void run_destroyers();
 };
 
 /// Special exit code which causes mumble to restart itself. The outward facing return code with be 0
 const int MUMBLE_EXIT_CODE_RESTART = 64738;
 
-// -Wshadow is bugged. If an inline function of a class uses a variable or
-// parameter named 'g', that will generate a warning even if the class header
-// is included long before this definition.
-
-#define g (*Global::g_global_struct)
-
 #endif
