@@ -1,46 +1,48 @@
-// Copyright 2005-2019 The Mumble Developers. All rights reserved.
+// Copyright 2010-2022 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
 
-#include "mumble_pch.hpp"
-
 #include "OverlayClient.h"
-#include "OverlayPositionableItem.h"
-#include "OverlayEditor.h"
-#include "OverlayText.h"
-#include "User.h"
 #include "Channel.h"
-#include "Message.h"
 #include "Database.h"
-#include "NetworkConfig.h"
-#include "ServerHandler.h"
 #include "MainWindow.h"
-#include "GlobalShortcut.h"
+#include "NetworkConfig.h"
+#include "OverlayEditor.h"
+#include "OverlayPositionableItem.h"
+#include "OverlayText.h"
+#include "ServerHandler.h"
 #include "Themes.h"
-
-// We define a global macro called 'g'. This can lead to issues when included code uses 'g' as a type or parameter name (like protobuf 3.7 does). As such, for now, we have to make this our last include.
+#include "User.h"
+#include "Utils.h"
 #include "Global.h"
+#include "GlobalShortcut.h"
+
+#ifdef Q_OS_WIN
+#	include <QtGui/QBitmap>
+#endif
+
+#include <QtGui/QImageReader>
+#include <QtWidgets/QGraphicsProxyWidget>
+
+#ifdef Q_OS_WIN
+#	include <psapi.h>
+#endif
 
 OverlayClient::OverlayClient(QLocalSocket *socket, QObject *p)
-	: QObject(p)
-	, framesPerSecond(0)
-	, ougUsers(&g.s.os)
-	, iMouseX(0)
-	, iMouseY(0) {
-	
+	: QObject(p), framesPerSecond(0), ougUsers(&Global::get().s.os), iMouseX(0), iMouseY(0) {
 	qlsSocket = socket;
-	qlsSocket->setParent(NULL);
+	qlsSocket->setParent(nullptr);
 	connect(qlsSocket, SIGNAL(readyRead()), this, SLOT(readyRead()));
 
 	omMsg.omh.iLength = -1;
-	smMem = NULL;
+	smMem             = nullptr;
 	uiWidth = uiHeight = 0;
 
 	uiPid = ~0ULL;
 
 	bWasVisible = false;
-	bDelete = false;
+	bDelete     = false;
 
 	qgv.setScene(&qgs);
 	qgv.installEventFilter(this);
@@ -49,7 +51,7 @@ OverlayClient::OverlayClient(QLocalSocket *socket, QObject *p)
 	// Make sure it has a native window id
 	qgv.winId();
 
-	qgpiCursor = new OverlayMouse();
+	qgpiCursor.reset(new OverlayMouse());
 	qgpiCursor->hide();
 	qgpiCursor->setZValue(10.0f);
 
@@ -57,36 +59,29 @@ OverlayClient::OverlayClient(QLocalSocket *socket, QObject *p)
 	qgs.addItem(&ougUsers);
 	ougUsers.show();
 
-	qgpiFPS = new OverlayPositionableItem(&g.s.os.qrfFps);
-	qgs.addItem(qgpiFPS);
-	qgpiFPS->setPos(g.s.os.qrfFps.x(), g.s.os.qrfFps.y());
+	qgpiFPS.reset(new OverlayPositionableItem(&Global::get().s.os.qrfFps));
+	qgs.addItem(qgpiFPS.data());
+	qgpiFPS->setPos(Global::get().s.os.qrfFps.x(), Global::get().s.os.qrfFps.y());
 	qgpiFPS->show();
 
 	// Time
-	qgpiTime = new OverlayPositionableItem(&g.s.os.qrfTime);
-	qgs.addItem(qgpiTime);
-	qgpiTime->setPos(g.s.os.qrfTime.x(), g.s.os.qrfTime.y());
+	qgpiTime.reset(new OverlayPositionableItem(&Global::get().s.os.qrfTime));
+	qgs.addItem(qgpiTime.data());
+	qgpiTime->setPos(Global::get().s.os.qrfTime.x(), Global::get().s.os.qrfTime.y());
 	qgpiTime->show();
 
-	qgpiLogo = NULL;
-
 	iOffsetX = iOffsetY = 0;
 
-	connect(&qgs, SIGNAL(changed(const QList<QRectF> &)), this, SLOT(changed(const QList<QRectF> &)));
+	connect(&qgs, SIGNAL(changed(const QList< QRectF > &)), this, SLOT(changed(const QList< QRectF > &)));
 }
 
 OverlayClient::~OverlayClient() {
-	delete qgpiFPS;
-	delete qgpiTime;
-	delete qgpiCursor;
-	delete qgpiLogo;
-
 	qlsSocket->disconnectFromServer();
 	if (!qlsSocket->waitForDisconnected(1000)) {
 		qDebug() << "OverlayClient: Failed to cleanly disconnect: " << qlsSocket->errorString();
 		qlsSocket->abort();
 	}
-	
+
 	qlsSocket->deleteLater();
 
 	ougUsers.reset();
@@ -101,14 +96,14 @@ bool OverlayClient::eventFilter(QObject *o, QEvent *e) {
 }
 
 void OverlayClient::updateFPS() {
-	if (g.s.os.bFps) {
-		const BasepointPixmap &pm = OverlayTextLine(
-		            QString(QLatin1String("%1")).arg(iroundf(framesPerSecond + 0.5f)),
-		            g.s.os.qfFps).createPixmap(g.s.os.qcFps);
+	if (Global::get().s.os.bFps) {
+		const BasepointPixmap &pm =
+			OverlayTextLine(QString(QLatin1String("%1")).arg(iroundf(framesPerSecond + 0.5f)), Global::get().s.os.qfFps)
+				.createPixmap(Global::get().s.os.qcFps);
 		qgpiFPS->setVisible(true);
 		qgpiFPS->setPixmap(pm);
 		// offset to use basepoint
-		//TODO: settings are providing a top left anchor, so shift down by ascent
+		// TODO: settings are providing a top left anchor, so shift down by ascent
 		qgpiFPS->setOffset(-pm.qpBasePoint + QPoint(0, pm.iAscent));
 		qgpiFPS->updateRender();
 	} else {
@@ -117,8 +112,10 @@ void OverlayClient::updateFPS() {
 }
 
 void OverlayClient::updateTime() {
-	if (g.s.os.bTime) {
-		const BasepointPixmap &pm = OverlayTextLine(QString(QLatin1String("%1")).arg(QTime::currentTime().toString()), g.s.os.qfFps).createPixmap(g.s.os.qcFps);
+	if (Global::get().s.os.bTime) {
+		const BasepointPixmap &pm =
+			OverlayTextLine(QString(QLatin1String("%1")).arg(QTime::currentTime().toString()), Global::get().s.os.qfFps)
+				.createPixmap(Global::get().s.os.qcFps);
 		qgpiTime->setVisible(true);
 		qgpiTime->setPixmap(pm);
 		qgpiTime->setOffset(-pm.qpBasePoint + QPoint(0, pm.iAscent));
@@ -130,23 +127,15 @@ void OverlayClient::updateTime() {
 
 #if !defined(Q_OS_MAC) || (defined(Q_OS_MAC) && defined(USE_MAC_UNIVERSAL))
 void OverlayClient::updateMouse() {
-#if defined(Q_OS_WIN)
+#	if defined(Q_OS_WIN)
 	QPixmap pm;
 
 	HICON c = ::GetCursor();
-#if QT_VERSION < 0x050000
-	if (c == NULL)
-		c = qgv.viewport()->cursor().handle();
-#endif
-
 	ICONINFO info;
 	ZeroMemory(&info, sizeof(info));
-	if (c != NULL && ::GetIconInfo(c, &info)) {
-#if QT_VERSION >= 0x050000
+	if (c && ::GetIconInfo(c, &info)) {
 		extern QPixmap qt_pixmapFromWinHBITMAP(HBITMAP bitmap, int format = 0);
-#else
-# define qt_pixmapFromWinHBITMAP(bmp) QPixmap::fromWinHBITMAP(bmp)
-#endif
+
 		if (info.hbmColor) {
 			pm = qt_pixmapFromWinHBITMAP(info.hbmColor);
 			pm.setMask(QBitmap(qt_pixmapFromWinHBITMAP(info.hbmMask)));
@@ -160,16 +149,16 @@ void OverlayClient::updateMouse() {
 			QImage out(img.width(), h, QImage::Format_MonoLSB);
 			QImage outmask(img.width(), h, QImage::Format_MonoLSB);
 
-			for (int i=0;i<h; ++i) {
-				const quint32 *srcimg = reinterpret_cast<const quint32 *>(img.scanLine(i + h));
-				const quint32 *srcmask = reinterpret_cast<const quint32 *>(img.scanLine(i));
+			for (int i = 0; i < h; ++i) {
+				const quint32 *srcimg  = reinterpret_cast< const quint32 * >(img.scanLine(i + h));
+				const quint32 *srcmask = reinterpret_cast< const quint32 * >(img.scanLine(i));
 
-				quint32 *dstimg = reinterpret_cast<quint32 *>(out.scanLine(i));
-				quint32 *dstmask = reinterpret_cast<quint32 *>(outmask.scanLine(i));
+				quint32 *dstimg  = reinterpret_cast< quint32 * >(out.scanLine(i));
+				quint32 *dstmask = reinterpret_cast< quint32 * >(outmask.scanLine(i));
 
-				for (int j=0;j<w;++j) {
+				for (int j = 0; j < w; ++j) {
 					dstmask[j] = srcmask[j];
-					dstimg[j] = srcimg[j];
+					dstimg[j]  = srcimg[j];
 				}
 			}
 			pm = QBitmap::fromImage(out);
@@ -185,32 +174,24 @@ void OverlayClient::updateMouse() {
 	}
 
 	qgpiCursor->setPixmap(pm);
-#else
-#endif
+#	else
+#	endif
 
 	qgpiCursor->setPos(iMouseX - iOffsetX, iMouseY - iOffsetY);
 }
 #endif
 
-#if QT_VERSION < 0x050000 && (defined(Q_OS_WIN) || defined(Q_OS_MAC))
-extern bool Q_GUI_EXPORT qt_use_native_dialogs;
-#endif
-
 // Qt gets very very unhappy if we embed or unmbed the widget that an event is called from.
 // This means that if any modal dialog is open, we'll be in a event loop of an object
 // that we're about to reparent.
 
 void OverlayClient::showGui() {
-#if defined(QT3_SUPPORT) || (defined(Q_OS_WIN) && QT_VERSION < 0x050000)
-	if (QCoreApplication::loopLevel() > 1)
-		return;
-#else
 	int count = 0;
 
 	{
 		QWidgetList widgets = qApp->topLevelWidgets();
-		foreach(QWidget *w, widgets) {
-			if (w->isHidden() && (w != g.mw))
+		foreach (QWidget *w, widgets) {
+			if (w->isHidden() && (w != Global::get().mw))
 				continue;
 			count++;
 		}
@@ -218,36 +199,35 @@ void OverlayClient::showGui() {
 	// If there's more than one window up, we're likely deep in a message loop.
 	if (count > 1)
 		return;
-#endif
 
-	g.ocIntercept = this;
+	Global::get().ocIntercept = this;
 
-	bWasVisible = ! g.mw->isHidden();
+	bWasVisible = !Global::get().mw->isHidden();
 
 	if (bWasVisible) {
-		if (g.s.bMinimalView) {
-			g.s.qbaMinimalViewGeometry = g.mw->saveGeometry();
-			g.s.qbaMinimalViewState = g.mw->saveState();
+		if (Global::get().s.bMinimalView) {
+			Global::get().s.qbaMinimalViewGeometry = Global::get().mw->saveGeometry();
+			Global::get().s.qbaMinimalViewState    = Global::get().mw->saveState();
 		} else {
-			g.s.qbaMainWindowGeometry = g.mw->saveGeometry();
-			g.s.qbaMainWindowState = g.mw->saveState();
-			g.s.qbaHeaderState = g.mw->qtvUsers->header()->saveState();
+			Global::get().s.qbaMainWindowGeometry = Global::get().mw->saveGeometry();
+			Global::get().s.qbaMainWindowState    = Global::get().mw->saveState();
+			Global::get().s.qbaHeaderState        = Global::get().mw->qtvUsers->header()->saveState();
 		}
 	}
 
 	{
-outer:
+	outer:
 		QWidgetList widgets = qApp->topLevelWidgets();
-		widgets.removeAll(g.mw);
-		widgets.prepend(g.mw);
+		widgets.removeAll(Global::get().mw);
+		widgets.prepend(Global::get().mw);
 
-		foreach(QWidget *w, widgets) {
-			if (w->graphicsProxyWidget() == NULL) {
-				if ((w == g.mw) || (! w->isHidden())) {
-					QGraphicsProxyWidget *qgpw = new QGraphicsProxyWidget(NULL, Qt::Window);
+		foreach (QWidget *w, widgets) {
+			if (!w->graphicsProxyWidget()) {
+				if ((w == Global::get().mw) || (!w->isHidden())) {
+					QGraphicsProxyWidget *qgpw = new QGraphicsProxyWidget(nullptr, Qt::Window);
 					qgpw->setOpacity(0.90f);
 					qgpw->setWidget(w);
-					if (w == g.mw) {
+					if (w == Global::get().mw) {
 						qgpw->setPos(uiWidth / 10, uiHeight / 10);
 						qgpw->resize((uiWidth * 8) / 10, (uiHeight * 8) / 10);
 					}
@@ -265,16 +245,16 @@ outer:
 	qApp->sendEvent(&qgs, &activateEvent);
 
 	QPoint p = QCursor::pos();
-	iMouseX = qBound<int>(0, p.x(), uiWidth-1);
-	iMouseY = qBound<int>(0, p.y(), uiHeight-1);
+	iMouseX  = qBound< int >(0, p.x(), uiWidth - 1);
+	iMouseY  = qBound< int >(0, p.y(), uiHeight - 1);
 
 	qgpiCursor->setPos(iMouseX, iMouseY);
 
 	qgs.setFocus();
 #ifndef Q_OS_MAC
-	g.mw->qteChat->activateWindow();
+	Global::get().mw->qteChat->activateWindow();
 #endif
-	g.mw->qteChat->setFocus();
+	Global::get().mw->qteChat->setFocus();
 
 	qgv.setAttribute(Qt::WA_WState_Hidden, false);
 	qApp->setActiveWindow(&qgv);
@@ -284,42 +264,30 @@ outer:
 
 #ifdef Q_OS_MAC
 	qApp->setAttribute(Qt::AA_DontUseNativeMenuBar);
-	g.mw->setUnifiedTitleAndToolBarOnMac(false);
-	if (! g.s.os.qsStyle.isEmpty())
-		qApp->setStyle(g.s.os.qsStyle);
+	Global::get().mw->setUnifiedTitleAndToolBarOnMac(false);
+	if (!Global::get().s.os.qsStyle.isEmpty())
+		qApp->setStyle(Global::get().s.os.qsStyle);
 #endif
 
 	setupScene(true);
 
-#if QT_VERSION < 0x050000 && (defined(Q_OS_WIN) || defined(Q_OS_MAC))
-	qt_use_native_dialogs = false;
-#endif
-
 	OverlayMsg om;
 	om.omh.uiMagic = OVERLAY_MAGIC_NUMBER;
-	om.omh.uiType = OVERLAY_MSGTYPE_INTERACTIVE;
+	om.omh.uiType  = OVERLAY_MSGTYPE_INTERACTIVE;
 	om.omh.iLength = sizeof(struct OverlayMsgInteractive);
-	om.omin.state = true;
+	om.omin.state  = true;
 	qlsSocket->write(om.headerbuffer, sizeof(OverlayMsgHeader) + om.omh.iLength);
 
-	g.o->updateOverlay();
+	Global::get().o->updateOverlay();
 }
 
 void OverlayClient::hideGui() {
-#if defined(QT3_SUPPORT) || (defined(Q_OS_WIN) && QT_VERSION < 0x050000)
-	if (QCoreApplication::loopLevel() > 1) {
-		QCoreApplication::exit_loop();
-		QMetaObject::invokeMethod(this, "hideGui", Qt::QueuedConnection);
-		return;
-	}
-#endif
-
 	ougUsers.bShowExamples = false;
 
-	QList<QWidget *> widgetlist;
+	QList< QWidget * > widgetlist;
 
-	foreach(QGraphicsItem *qgi, qgs.items(Qt::DescendingOrder)) {
-		QGraphicsProxyWidget *qgpw = qgraphicsitem_cast<QGraphicsProxyWidget *>(qgi);
+	foreach (QGraphicsItem *qgi, qgs.items(Qt::DescendingOrder)) {
+		QGraphicsProxyWidget *qgpw = qgraphicsitem_cast< QGraphicsProxyWidget * >(qgi);
 		if (qgpw && qgpw->widget()) {
 			QWidget *w = qgpw->widget();
 
@@ -328,54 +296,51 @@ void OverlayClient::hideGui() {
 		}
 	}
 
-	foreach(QWidget *w, widgetlist) {
+	foreach (QWidget *w, widgetlist) {
 		QGraphicsProxyWidget *qgpw = w->graphicsProxyWidget();
 		if (qgpw) {
 			qgpw->setVisible(false);
-			qgpw->setWidget(NULL);
+			qgpw->setWidget(nullptr);
 			delete qgpw;
 		}
 	}
 
-	if (g.ocIntercept == this)
-		g.ocIntercept = NULL;
+	if (Global::get().ocIntercept == this)
+		Global::get().ocIntercept = nullptr;
 
-	foreach(QWidget *w, widgetlist) {
+	foreach (QWidget *w, widgetlist) {
 		if (bWasVisible)
 			w->show();
 	}
 
 	if (bWasVisible) {
-		if (g.s.bMinimalView && ! g.s.qbaMinimalViewGeometry.isNull()) {
-			g.mw->restoreGeometry(g.s.qbaMinimalViewGeometry);
-			g.mw->restoreState(g.s.qbaMinimalViewState);
-		} else if (! g.s.bMinimalView && ! g.s.qbaMainWindowGeometry.isNull()) {
-			g.mw->restoreGeometry(g.s.qbaMainWindowGeometry);
-			g.mw->restoreState(g.s.qbaMainWindowState);
+		if (Global::get().s.bMinimalView && !Global::get().s.qbaMinimalViewGeometry.isNull()) {
+			Global::get().mw->restoreGeometry(Global::get().s.qbaMinimalViewGeometry);
+			Global::get().mw->restoreState(Global::get().s.qbaMinimalViewState);
+		} else if (!Global::get().s.bMinimalView && !Global::get().s.qbaMainWindowGeometry.isNull()) {
+			Global::get().mw->restoreGeometry(Global::get().s.qbaMainWindowGeometry);
+			Global::get().mw->restoreState(Global::get().s.qbaMainWindowState);
 		}
 	}
 
 #ifdef Q_OS_MAC
 	qApp->setAttribute(Qt::AA_DontUseNativeMenuBar, false);
-	g.mw->setUnifiedTitleAndToolBarOnMac(true);
+	Global::get().mw->setUnifiedTitleAndToolBarOnMac(true);
 	Themes::apply();
 #endif
 
 	setupScene(false);
 
 	qgv.setAttribute(Qt::WA_WState_Hidden, true);
-#if QT_VERSION < 0x050000 && (defined(Q_OS_WIN) || defined(Q_OS_MAC))
-	qt_use_native_dialogs = true;
-#endif
 
 	OverlayMsg om;
 	om.omh.uiMagic = OVERLAY_MAGIC_NUMBER;
-	om.omh.uiType = OVERLAY_MSGTYPE_INTERACTIVE;
+	om.omh.uiType  = OVERLAY_MSGTYPE_INTERACTIVE;
 	om.omh.iLength = sizeof(struct OverlayMsgInteractive);
-	om.omin.state = false;
+	om.omin.state  = false;
 	qlsSocket->write(om.headerbuffer, sizeof(OverlayMsgHeader) + om.omh.iLength);
 
-	g.o->updateOverlay();
+	Global::get().o->updateOverlay();
 
 	if (bDelete)
 		deleteLater();
@@ -391,48 +356,49 @@ void OverlayClient::readyReadMsgInit(unsigned int length) {
 		return;
 	}
 
-	OverlayMsgInit *omi = & omMsg.omi;
+	OverlayMsgInit *omi = &omMsg.omi;
 
-	uiWidth = omi->uiWidth;
+	uiWidth  = omi->uiWidth;
 	uiHeight = omi->uiHeight;
-	qrLast = QRect();
+	qrLast   = QRect();
 
 	delete smMem;
 
 	smMem = new SharedMemory2(this, uiWidth * uiHeight * 4);
-	if (! smMem->data()) {
+	if (!smMem->data()) {
 		qWarning() << "OverlayClient: Failed to create shared memory" << uiWidth << uiHeight;
 		delete smMem;
-		smMem = NULL;
+		smMem = nullptr;
 		return;
 	}
 	QByteArray key = smMem->name().toUtf8();
-	key.append(static_cast<char>(0));
+	key.append(static_cast< char >(0));
 
 	OverlayMsg om;
 	om.omh.uiMagic = OVERLAY_MAGIC_NUMBER;
-	om.omh.uiType = OVERLAY_MSGTYPE_SHMEM;
+	om.omh.uiType  = OVERLAY_MSGTYPE_SHMEM;
 	om.omh.iLength = key.length();
-	Q_ASSERT(sizeof(om.oms.a_cName) >= static_cast<size_t>(key.length())); // Name should be auto-generated and short
+	Q_ASSERT(sizeof(om.oms.a_cName) >= static_cast< size_t >(key.length())); // Name should be auto-generated and short
 	memcpy(om.oms.a_cName, key.constData(), key.length());
 	qlsSocket->write(om.headerbuffer, sizeof(OverlayMsgHeader) + om.omh.iLength);
 
 	setupRender();
 
-	Overlay *o = static_cast<Overlay *>(parent());
+	Overlay *o = static_cast< Overlay * >(parent());
 	QTimer::singleShot(0, o, SLOT(updateOverlay()));
 }
 
 void OverlayClient::readyRead() {
 	while (true) {
-		quint64 ready = static_cast<quint64>(qlsSocket->bytesAvailable());
+		quint64 ready = static_cast< quint64 >(qlsSocket->bytesAvailable());
 
 		if (omMsg.omh.iLength == -1) {
 			if (ready < sizeof(OverlayMsgHeader)) {
 				break;
 			} else {
 				qlsSocket->read(omMsg.headerbuffer, sizeof(OverlayMsgHeader));
-				if ((omMsg.omh.uiMagic != OVERLAY_MAGIC_NUMBER) || (omMsg.omh.iLength < 0) || (omMsg.omh.iLength > static_cast<int>(sizeof(OverlayMsgShmem)))) {
+				if ((omMsg.omh.uiMagic != OVERLAY_MAGIC_NUMBER) || (omMsg.omh.iLength < 0)
+					|| (omMsg.omh.iLength > static_cast< int >(sizeof(OverlayMsgShmem)))) {
 					disconnect();
 					return;
 				}
@@ -440,7 +406,7 @@ void OverlayClient::readyRead() {
 			}
 		}
 
-		if (ready >= static_cast<unsigned int>(omMsg.omh.iLength)) {
+		if (ready >= static_cast< unsigned int >(omMsg.omh.iLength)) {
 			qint64 length = qlsSocket->read(omMsg.msgbuffer, omMsg.omh.iLength);
 
 			if (length != omMsg.omh.iLength) {
@@ -450,46 +416,42 @@ void OverlayClient::readyRead() {
 
 			switch (omMsg.omh.uiType) {
 				case OVERLAY_MSGTYPE_INIT: {
-						readyReadMsgInit(static_cast<unsigned int>(length));
-					}
-					break;
+					readyReadMsgInit(static_cast< unsigned int >(length));
+				} break;
 				case OVERLAY_MSGTYPE_SHMEM: {
-						if (smMem)
-							smMem->systemRelease();
-					}
-					break;
+					if (smMem)
+						smMem->systemRelease();
+				} break;
 				case OVERLAY_MSGTYPE_PID: {
-						if (length != static_cast<qint64>(sizeof(OverlayMsgPid)))
-							break;
+					if (length != static_cast< qint64 >(sizeof(OverlayMsgPid)))
+						break;
 
-						OverlayMsgPid *omp = & omMsg.omp;
-						uiPid = omp->pid;
+					OverlayMsgPid *omp = &omMsg.omp;
+					uiPid              = omp->pid;
 #ifdef Q_OS_WIN
-						HANDLE h = OpenProcess(PROCESS_QUERY_INFORMATION | PROCESS_VM_READ, FALSE, (DWORD)uiPid);
-						if (h) {
-							wchar_t buf[MAX_PATH];
-							if (GetModuleFileNameEx(h, 0, buf, MAX_PATH) != 0) {
-								qsExecutablePath = QString::fromWCharArray(buf);
-							}
-							CloseHandle(h);
+					HANDLE h = OpenProcess(PROCESS_QUERY_INFORMATION | PROCESS_VM_READ, FALSE, (DWORD) uiPid);
+					if (h) {
+						wchar_t buf[MAX_PATH];
+						if (GetModuleFileNameEx(h, 0, buf, MAX_PATH) != 0) {
+							qsExecutablePath = QString::fromWCharArray(buf);
 						}
+						CloseHandle(h);
+					}
 #else
-						qsExecutablePath = QLatin1String("Unknown");
+					qsExecutablePath = QLatin1String("Unknown");
 #endif
-					}
-					break;
+				} break;
 				case OVERLAY_MSGTYPE_FPS: {
-						if (length != sizeof(OverlayMsgFps))
-							break;
+					if (length != sizeof(OverlayMsgFps))
+						break;
 
-						OverlayMsgFps *omf = & omMsg.omf;
-						framesPerSecond = omf->fps;
-						//qWarning() << "FPS: " << omf->fps;
+					OverlayMsgFps *omf = &omMsg.omf;
+					framesPerSecond    = omf->fps;
+					// qWarning() << "FPS: " << omf->fps;
 
-						Overlay *o = static_cast<Overlay *>(parent());
-						QTimer::singleShot(0, o, SLOT(updateOverlay()));
-					}
-					break;
+					Overlay *o = static_cast< Overlay * >(parent());
+					QTimer::singleShot(0, o, SLOT(updateOverlay()));
+				} break;
 				default:
 					break;
 			}
@@ -501,23 +463,22 @@ void OverlayClient::readyRead() {
 }
 
 void OverlayClient::reset() {
-	if (! uiWidth || ! uiHeight || ! smMem)
+	if (!uiWidth || !uiHeight || !smMem)
 		return;
 
-	delete qgpiLogo;
-	qgpiLogo = NULL;
+	qgpiLogo.reset();
 
 	ougUsers.reset();
 
-	setupScene(g.ocIntercept == this);
+	setupScene(Global::get().ocIntercept == this);
 }
 
 void OverlayClient::setupScene(bool show) {
 	if (show) {
-		qgs.setBackgroundBrush(QColor(0,0,0,64));
+		qgs.setBackgroundBrush(QColor(0, 0, 0, 64));
 
-		if (! qgpiLogo) {
-			qgpiLogo = new OverlayMouse();
+		if (!qgpiLogo) {
+			qgpiLogo.reset(new OverlayMouse());
 			qgpiLogo->hide();
 			qgpiLogo->setOpacity(0.8f);
 			qgpiLogo->setZValue(-5.0f);
@@ -531,28 +492,27 @@ void OverlayClient::setupScene(bool show) {
 			qgpiLogo->setPixmap(QPixmap::fromImage(qir.read()));
 
 			QRectF qrf = qgpiLogo->boundingRect();
-			qgpiLogo->setPos(iroundf((uiWidth - qrf.width()) / 2.0f + 0.5f), iroundf((uiHeight - qrf.height()) / 2.0f + 0.5f));
-
+			qgpiLogo->setPos(iroundf((uiWidth - qrf.width()) / 2.0f + 0.5f),
+							 iroundf((uiHeight - qrf.height()) / 2.0f + 0.5f));
 		}
 
 		qgpiCursor->show();
-		qgs.addItem(qgpiCursor);
+		qgs.addItem(qgpiCursor.data());
 
 		qgpiLogo->show();
-		qgs.addItem(qgpiLogo);
+		qgs.addItem(qgpiLogo.data());
 	} else {
 		qgs.setBackgroundBrush(Qt::NoBrush);
 
 		if (qgpiCursor->scene())
-			qgs.removeItem(qgpiCursor);
+			qgs.removeItem(qgpiCursor.data());
 		qgpiCursor->hide();
 
 		if (qgpiLogo) {
 			if (qgpiLogo->scene())
-				qgs.removeItem(qgpiLogo);
+				qgs.removeItem(qgpiLogo.data());
 			qgpiLogo->hide();
 		}
-
 	}
 	ougUsers.updateUsers();
 	updateFPS();
@@ -561,7 +521,7 @@ void OverlayClient::setupScene(bool show) {
 
 void OverlayClient::setupRender() {
 	qgs.setSceneRect(0, 0, uiWidth, uiHeight);
-	qgv.setScene(NULL);
+	qgv.setScene(nullptr);
 	qgv.setGeometry(-2, -2, uiWidth + 2, uiHeight + 2);
 	qgv.viewport()->setGeometry(0, 0, uiWidth, uiHeight);
 	qgv.setScene(&qgs);
@@ -570,19 +530,19 @@ void OverlayClient::setupRender() {
 
 	OverlayMsg om;
 	om.omh.uiMagic = OVERLAY_MAGIC_NUMBER;
-	om.omh.uiType = OVERLAY_MSGTYPE_BLIT;
+	om.omh.uiType  = OVERLAY_MSGTYPE_BLIT;
 	om.omh.iLength = sizeof(OverlayMsgBlit);
-	om.omb.x = 0;
-	om.omb.y = 0;
-	om.omb.w = uiWidth;
-	om.omb.h = uiHeight;
+	om.omb.x       = 0;
+	om.omb.y       = 0;
+	om.omb.w       = uiWidth;
+	om.omb.h       = uiHeight;
 	qlsSocket->write(om.headerbuffer, sizeof(OverlayMsgHeader) + sizeof(OverlayMsgBlit));
 
 	reset();
 }
 
 bool OverlayClient::update() {
-	if (! uiWidth || ! uiHeight || ! smMem)
+	if (!uiWidth || !uiHeight || !smMem)
 		return true;
 
 	ougUsers.updateUsers();
@@ -597,7 +557,7 @@ bool OverlayClient::update() {
 	}
 }
 
-void OverlayClient::changed(const QList<QRectF> &region) {
+void OverlayClient::changed(const QList< QRectF > &region) {
 	if (region.isEmpty())
 		return;
 
@@ -606,10 +566,10 @@ void OverlayClient::changed(const QList<QRectF> &region) {
 }
 
 void OverlayClient::render() {
-	const QList<QRectF> region = qlDirty;
+	const QList< QRectF > region = qlDirty;
 	qlDirty.clear();
 
-	if (! uiWidth || ! uiHeight || ! smMem)
+	if (!uiWidth || !uiHeight || !smMem)
 		return;
 
 	QRect active;
@@ -618,21 +578,20 @@ void OverlayClient::render() {
 	if (region.isEmpty())
 		return;
 
-	foreach(const QRectF &r, region) {
-		dirtyf |= r;
-	}
+	foreach (const QRectF &r, region) { dirtyf |= r; }
 
 
 	QRect dirty = dirtyf.toAlignedRect();
-	dirty = dirty.intersected(QRect(0,0,uiWidth, uiHeight));
+	dirty       = dirty.intersected(QRect(0, 0, uiWidth, uiHeight));
 
 	if ((dirty.width() <= 0) || (dirty.height() <= 0))
 		return;
 
 	QRect target = dirty;
-	target.moveTo(0,0);
+	target.moveTo(0, 0);
 
-	QImage img(reinterpret_cast<unsigned char *>(smMem->data()), uiWidth, uiHeight, QImage::Format_ARGB32_Premultiplied);
+	QImage img(reinterpret_cast< unsigned char * >(smMem->data()), uiWidth, uiHeight,
+			   QImage::Format_ARGB32_Premultiplied);
 	QImage qi(target.size(), QImage::Format_ARGB32_Premultiplied);
 	qi.fill(0);
 
@@ -652,22 +611,22 @@ void OverlayClient::render() {
 	if (dirty.isValid()) {
 		OverlayMsg om;
 		om.omh.uiMagic = OVERLAY_MAGIC_NUMBER;
-		om.omh.uiType = OVERLAY_MSGTYPE_BLIT;
+		om.omh.uiType  = OVERLAY_MSGTYPE_BLIT;
 		om.omh.iLength = sizeof(OverlayMsgBlit);
-		om.omb.x = dirty.x();
-		om.omb.y = dirty.y();
-		om.omb.w = dirty.width();
-		om.omb.h = dirty.height();
+		om.omb.x       = dirty.x();
+		om.omb.y       = dirty.y();
+		om.omb.w       = dirty.width();
+		om.omb.h       = dirty.height();
 		qlsSocket->write(om.headerbuffer, sizeof(OverlayMsgHeader) + sizeof(OverlayMsgBlit));
 	}
 
 	if (qgpiCursor->isVisible()) {
-		active = QRect(0,0,uiWidth,uiHeight);
+		active = QRect(0, 0, uiWidth, uiHeight);
 	} else {
 		active = qgs.itemsBoundingRect().toAlignedRect();
 		if (active.isEmpty())
-			active = QRect(0,0,0,0);
-		active = active.intersected(QRect(0,0,uiWidth,uiHeight));
+			active = QRect(0, 0, 0, 0);
+		active = active.intersected(QRect(0, 0, uiWidth, uiHeight));
 	}
 
 	if (active != qrLast) {
@@ -675,12 +634,12 @@ void OverlayClient::render() {
 
 		OverlayMsg om;
 		om.omh.uiMagic = OVERLAY_MAGIC_NUMBER;
-		om.omh.uiType = OVERLAY_MSGTYPE_ACTIVE;
+		om.omh.uiType  = OVERLAY_MSGTYPE_ACTIVE;
 		om.omh.iLength = sizeof(OverlayMsgActive);
-		om.oma.x = qrLast.x();
-		om.oma.y = qrLast.y();
-		om.oma.w = qrLast.width();
-		om.oma.h = qrLast.height();
+		om.oma.x       = qrLast.x();
+		om.oma.y       = qrLast.y();
+		om.oma.w       = qrLast.width();
+		om.oma.h       = qrLast.height();
 		qlsSocket->write(om.headerbuffer, sizeof(OverlayMsgHeader) + sizeof(OverlayMsgActive));
 	}
 
@@ -688,7 +647,7 @@ void OverlayClient::render() {
 }
 
 void OverlayClient::openEditor() {
-	OverlayEditor oe(g.mw, &ougUsers);
+	OverlayEditor oe(Global::get().mw, &ougUsers);
 	connect(&oe, SIGNAL(applySettings()), this, SLOT(updateLayout()));
 
 	oe.exec();
