@@ -1,54 +1,29 @@
-/* Copyright (C) 2005-2011, Thorvald Natvig <thorvald@natvig.com>
+// Copyright 2010-2022 The Mumble Developers. All rights reserved.
+// Use of this source code is governed by a BSD-style license
+// that can be found in the LICENSE file at the root of the
+// Mumble source tree or at <https://www.mumble.info/LICENSE>.
 
-   All rights reserved.
+#include "OverlayEditor.h"
 
-   Redistribution and use in source and binary forms, with or without
-   modification, are permitted provided that the following conditions
-   are met:
-
-   - Redistributions of source code must retain the above copyright notice,
-     this list of conditions and the following disclaimer.
-   - Redistributions in binary form must reproduce the above copyright notice,
-     this list of conditions and the following disclaimer in the documentation
-     and/or other materials provided with the distribution.
-   - Neither the name of the Mumble Developers nor the names of its
-     contributors may be used to endorse or promote products derived from this
-     software without specific prior written permission.
-
-   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-   ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
-   A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR
-   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
-   EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
-   PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
-   PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
-   LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
-   NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
-   SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-*/
-
-#include "mumble_pch.hpp"
-
-#include "Overlay.h"
-#include "OverlayText.h"
-#include "User.h"
 #include "Channel.h"
-#include "Global.h"
-#include "Message.h"
 #include "Database.h"
-#include "NetworkConfig.h"
-#include "ServerHandler.h"
 #include "MainWindow.h"
+#include "NetworkConfig.h"
+#include "OverlayClient.h"
+#include "OverlayText.h"
+#include "ServerHandler.h"
+#include "User.h"
+#include "Utils.h"
+#include "Global.h"
 #include "GlobalShortcut.h"
 
-OverlayEditor::OverlayEditor(QWidget *p, QGraphicsItem *qgi, OverlaySettings *osptr) :
-		QDialog(p),
-		qgiPromote(qgi),
-		oes(g.s.os) {
-	setupUi(this);
+#include <QtWidgets/QGraphicsProxyWidget>
 
-	os = osptr ? osptr : &g.s.os;
+OverlayEditor::OverlayEditor(QWidget *p, QGraphicsItem *qgi, OverlaySettings *osptr)
+	: QDialog(p), qgiPromote(qgi), oes(Global::get().s.os) {
+	setupUi(this);
+	qsZoom->setAccessibleName(tr("Zoom level"));
+	os = osptr ? osptr : &Global::get().s.os;
 
 	connect(qdbbBox->button(QDialogButtonBox::Apply), SIGNAL(clicked()), this, SLOT(apply()));
 	connect(qdbbBox->button(QDialogButtonBox::Reset), SIGNAL(clicked()), this, SLOT(reset()));
@@ -56,9 +31,11 @@ OverlayEditor::OverlayEditor(QWidget *p, QGraphicsItem *qgi, OverlaySettings *os
 	QGraphicsProxyWidget *qgpw = graphicsProxyWidget();
 	if (qgpw) {
 		qgpw->setFlag(QGraphicsItem::ItemIgnoresParentOpacity);
-		if (g.ocIntercept) {
-			qgpw->setPos(iroundf(g.ocIntercept->uiWidth / 16.0f + 0.5f), iroundf(g.ocIntercept->uiHeight / 16.0f + 0.5f));
-			qgpw->resize(iroundf(g.ocIntercept->uiWidth * 14.0f / 16.0f + 0.5f), iroundf(g.ocIntercept->uiHeight * 14.0f / 16.0f + 0.5f));
+		if (Global::get().ocIntercept) {
+			qgpw->setPos(iroundf(static_cast< float >(Global::get().ocIntercept->uiWidth) / 16.0f + 0.5f),
+						 iroundf(static_cast< float >(Global::get().ocIntercept->uiHeight) / 16.0f + 0.5f));
+			qgpw->resize(iroundf(static_cast< float >(Global::get().ocIntercept->uiWidth) * 14.0f / 16.0f + 0.5f),
+						 iroundf(static_cast< float >(Global::get().ocIntercept->uiHeight) * 14.0f / 16.0f + 0.5f));
 		}
 	}
 
@@ -68,15 +45,15 @@ OverlayEditor::OverlayEditor(QWidget *p, QGraphicsItem *qgi, OverlaySettings *os
 }
 
 OverlayEditor::~OverlayEditor() {
-	QGraphicsProxyWidget *qgpw = g.mw->graphicsProxyWidget();
+	QGraphicsProxyWidget *qgpw = Global::get().mw->graphicsProxyWidget();
 	if (qgpw)
 		qgpw->setOpacity(0.9f);
 	if (qgiPromote)
 		qgiPromote->setZValue(-1.0f);
 }
 
-void OverlayEditor::enterEvent(QEvent *event) {
-	QGraphicsProxyWidget *qgpw = g.mw->graphicsProxyWidget();
+void OverlayEditor::enterEvent(QEvent *e) {
+	QGraphicsProxyWidget *qgpw = Global::get().mw->graphicsProxyWidget();
 	if (qgpw)
 		qgpw->setOpacity(0.9f);
 
@@ -87,11 +64,11 @@ void OverlayEditor::enterEvent(QEvent *event) {
 	if (qgiPromote)
 		qgiPromote->setZValue(-1.0f);
 
-	QDialog::enterEvent(event);
+	QDialog::enterEvent(e);
 }
 
-void OverlayEditor::leaveEvent(QEvent *event) {
-	QGraphicsProxyWidget *qgpw = g.mw->graphicsProxyWidget();
+void OverlayEditor::leaveEvent(QEvent *e) {
+	QGraphicsProxyWidget *qgpw = Global::get().mw->graphicsProxyWidget();
 	if (qgpw)
 		qgpw->setOpacity(0.3f);
 
@@ -102,7 +79,7 @@ void OverlayEditor::leaveEvent(QEvent *event) {
 	if (qgiPromote)
 		qgiPromote->setZValue(1.0f);
 
-	QDialog::leaveEvent(event);
+	QDialog::leaveEvent(e);
 }
 
 void OverlayEditor::reset() {
@@ -148,7 +125,7 @@ void OverlayEditor::on_qrbShout_clicked() {
 
 void OverlayEditor::on_qcbAvatar_clicked() {
 	oes.os.bAvatar = qcbAvatar->isChecked();
-	if (! oes.os.bAvatar && ! oes.os.bUserName) {
+	if (!oes.os.bAvatar && !oes.os.bUserName) {
 		qcbUser->setChecked(true);
 		oes.os.bUserName = true;
 		oes.updateUserName();
@@ -158,7 +135,7 @@ void OverlayEditor::on_qcbAvatar_clicked() {
 
 void OverlayEditor::on_qcbUser_clicked() {
 	oes.os.bUserName = qcbUser->isChecked();
-	if (! oes.os.bAvatar && ! oes.os.bUserName) {
+	if (!oes.os.bAvatar && !oes.os.bUserName) {
 		qcbAvatar->setChecked(true);
 		oes.os.bAvatar = true;
 		oes.updateAvatar();
