@@ -1,53 +1,35 @@
-/* Copyright (C) 2005-2011, Thorvald Natvig <thorvald@natvig.com>
+// Copyright 2010-2022 The Mumble Developers. All rights reserved.
+// Use of this source code is governed by a BSD-style license
+// that can be found in the LICENSE file at the root of the
+// Mumble source tree or at <https://www.mumble.info/LICENSE>.
 
-   All rights reserved.
+#include "OverlayEditorScene.h"
 
-   Redistribution and use in source and binary forms, with or without
-   modification, are permitted provided that the following conditions
-   are met:
-
-   - Redistributions of source code must retain the above copyright notice,
-     this list of conditions and the following disclaimer.
-   - Redistributions in binary form must reproduce the above copyright notice,
-     this list of conditions and the following disclaimer in the documentation
-     and/or other materials provided with the distribution.
-   - Neither the name of the Mumble Developers nor the names of its
-     contributors may be used to endorse or promote products derived from this
-     software without specific prior written permission.
-
-   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-   ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
-   A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR
-   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
-   EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
-   PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
-   PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
-   LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
-   NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
-   SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-*/
-
-#include "mumble_pch.hpp"
-
-#include "Overlay.h"
-#include "OverlayText.h"
-#include "User.h"
 #include "Channel.h"
-#include "Global.h"
-#include "Message.h"
 #include "Database.h"
-#include "NetworkConfig.h"
-#include "ServerHandler.h"
 #include "MainWindow.h"
+#include "NetworkConfig.h"
+#include "OverlayClient.h"
+#include "OverlayText.h"
+#include "OverlayUser.h"
+#include "ServerHandler.h"
+#include "User.h"
+#include "Utils.h"
+#include "Global.h"
 #include "GlobalShortcut.h"
 
+#include <QtGui/QImageReader>
+#include <QtWidgets/QColorDialog>
+#include <QtWidgets/QFontDialog>
+#include <QtWidgets/QGraphicsProxyWidget>
+#include <QtWidgets/QGraphicsSceneMouseEvent>
+
 OverlayEditorScene::OverlayEditorScene(const OverlaySettings &srcos, QObject *p) : QGraphicsScene(p), os(srcos) {
 	tsColor = Settings::Talking;
-	uiZoom = 2;
+	uiZoom  = 2;
 
-	if (g.ocIntercept)
-		uiSize = g.ocIntercept->uiHeight;
+	if (Global::get().ocIntercept)
+		uiSize = Global::get().ocIntercept->uiHeight;
 	else
 		uiSize = 1080.f;
 
@@ -71,7 +53,7 @@ OverlayEditorScene::OverlayEditorScene(const OverlaySettings &srcos, QObject *p)
 	qgpiBox = new QGraphicsPathItem(qgiGroup);
 	qgpiBox->hide();
 
-	qgpiSelected = NULL;
+	qgpiSelected = nullptr;
 
 	qgriSelected = new QGraphicsRectItem;
 	qgriSelected->hide();
@@ -93,7 +75,8 @@ OverlayEditorScene::OverlayEditorScene(const OverlaySettings &srcos, QObject *p)
 	resync();
 }
 
-#define SCALESIZE(var) iroundf(uiSize * uiZoom * os.qrf##var .width() + 0.5f), iroundf(uiSize * uiZoom * os.qrf##var .height() + 0.5f)
+#define SCALESIZE(var) \
+	iroundf(uiSize *uiZoom *os.qrf##var.width() + 0.5f), iroundf(uiSize *uiZoom *os.qrf##var.height() + 0.5f)
 
 void OverlayEditorScene::updateMuted() {
 	QImageReader qir(QLatin1String("skin:muted_self.svg"));
@@ -107,7 +90,8 @@ void OverlayEditorScene::updateMuted() {
 
 void OverlayEditorScene::moveMuted() {
 	qgpiMuted->setVisible(os.bMutedDeafened);
-	qgpiMuted->setPos(OverlayUser::alignedPosition(OverlayUser::scaledRect(os.qrfMutedDeafened, uiSize * uiZoom), qgpiMuted->boundingRect(), os.qaMutedDeafened));
+	qgpiMuted->setPos(OverlayUser::alignedPosition(OverlayUser::scaledRect(os.qrfMutedDeafened, uiSize * uiZoom),
+												   qgpiMuted->boundingRect(), os.qaMutedDeafened));
 	qgpiMuted->setOpacity(os.fMutedDeafened);
 }
 
@@ -121,6 +105,9 @@ void OverlayEditorScene::updateUserName() {
 		case Settings::Talking:
 			qsName = Overlay::tr("Talking");
 			break;
+		case Settings::MutedTalking:
+			qsName = QObject::tr("Talking (muted)");
+			break;
 		case Settings::Whispering:
 			qsName = Overlay::tr("Whisper");
 			break;
@@ -129,7 +116,8 @@ void OverlayEditorScene::updateUserName() {
 			break;
 	}
 
-	const QPixmap &pm = OverlayTextLine(qsName, os.qfUserName).createPixmap(SCALESIZE(UserName), os.qcUserName[tsColor]);
+	const QPixmap &pm =
+		OverlayTextLine(qsName, os.qfUserName).createPixmap(SCALESIZE(UserName), os.qcUserName[tsColor]);
 	qgpiName->setPixmap(pm);
 
 	moveUserName();
@@ -137,12 +125,14 @@ void OverlayEditorScene::updateUserName() {
 
 void OverlayEditorScene::moveUserName() {
 	qgpiName->setVisible(os.bUserName);
-	qgpiName->setPos(OverlayUser::alignedPosition(OverlayUser::scaledRect(os.qrfUserName, uiSize * uiZoom), qgpiName->boundingRect(), os.qaUserName));
+	qgpiName->setPos(OverlayUser::alignedPosition(OverlayUser::scaledRect(os.qrfUserName, uiSize * uiZoom),
+												  qgpiName->boundingRect(), os.qaUserName));
 	qgpiName->setOpacity(os.fUserName);
 }
 
 void OverlayEditorScene::updateChannel() {
-	const QPixmap &pm = OverlayTextLine(Overlay::tr("Channel"), os.qfChannel).createPixmap(SCALESIZE(Channel), os.qcChannel);
+	const QPixmap &pm =
+		OverlayTextLine(Overlay::tr("Channel"), os.qfChannel).createPixmap(SCALESIZE(Channel), os.qcChannel);
 	qgpiChannel->setPixmap(pm);
 
 	moveChannel();
@@ -150,7 +140,8 @@ void OverlayEditorScene::updateChannel() {
 
 void OverlayEditorScene::moveChannel() {
 	qgpiChannel->setVisible(os.bChannel);
-	qgpiChannel->setPos(OverlayUser::alignedPosition(OverlayUser::scaledRect(os.qrfChannel, uiSize * uiZoom), qgpiChannel->boundingRect(), os.qaChannel));
+	qgpiChannel->setPos(OverlayUser::alignedPosition(OverlayUser::scaledRect(os.qrfChannel, uiSize * uiZoom),
+													 qgpiChannel->boundingRect(), os.qaChannel));
 	qgpiChannel->setOpacity(os.fChannel);
 }
 
@@ -168,23 +159,27 @@ void OverlayEditorScene::updateAvatar() {
 
 void OverlayEditorScene::moveAvatar() {
 	qgpiAvatar->setVisible(os.bAvatar);
-	qgpiAvatar->setPos(OverlayUser::alignedPosition(OverlayUser::scaledRect(os.qrfAvatar, uiSize * uiZoom), qgpiAvatar->boundingRect(), os.qaAvatar));
+	qgpiAvatar->setPos(OverlayUser::alignedPosition(OverlayUser::scaledRect(os.qrfAvatar, uiSize * uiZoom),
+													qgpiAvatar->boundingRect(), os.qaAvatar));
 	qgpiAvatar->setOpacity(os.fAvatar);
 }
 
 void OverlayEditorScene::moveBox() {
-	QRectF children = os.qrfAvatar | os.qrfChannel | os.qrfMutedDeafened | os.qrfUserName;
+	QRectF childrenBounds = os.qrfAvatar | os.qrfChannel | os.qrfMutedDeafened | os.qrfUserName;
 
-	bool haspen = (os.qcBoxPen != os.qcBoxFill) && (! qFuzzyCompare(os.qcBoxPen.alphaF(), static_cast<qreal>(0.0f)));
-	qreal pw = haspen ? qMax<qreal>(1.0f, os.fBoxPenWidth * uiSize * uiZoom) : 0.0f;
-	qreal pad = os.fBoxPad * uiSize * uiZoom;
+	bool haspen = (os.qcBoxPen != os.qcBoxFill) && (!qFuzzyCompare(os.qcBoxPen.alphaF(), static_cast< qreal >(0.0f)));
+	qreal pw    = haspen ? qMax< qreal >(1.0f, os.fBoxPenWidth * uiSize * uiZoom) : 0.0f;
+	qreal pad   = os.fBoxPad * uiSize * uiZoom;
 
 	QPainterPath pp;
-	pp.addRoundedRect(children.x() * uiSize * uiZoom + -pw / 2.0f - pad, children.y() * uiSize * uiZoom + -pw / 2.0f - pad, children.width() * uiSize * uiZoom + pw + 2.0f * pad, children.height() * uiSize * uiZoom + pw + 2.0f * pad, 2.0f * pw, 2.0f * pw);
+	pp.addRoundedRect(childrenBounds.x() * uiSize * uiZoom + -pw / 2.0f - pad,
+					  childrenBounds.y() * uiSize * uiZoom + -pw / 2.0f - pad,
+					  childrenBounds.width() * uiSize * uiZoom + pw + 2.0f * pad,
+					  childrenBounds.height() * uiSize * uiZoom + pw + 2.0f * pad, 2.0f * pw, 2.0f * pw);
 	qgpiBox->setPath(pp);
 	qgpiBox->setPos(0.0f, 0.0f);
 	qgpiBox->setPen(haspen ? QPen(os.qcBoxPen, pw) : Qt::NoPen);
-	qgpiBox->setBrush(qFuzzyCompare(os.qcBoxFill.alphaF(), static_cast<qreal>(0.0f)) ? Qt::NoBrush : os.qcBoxFill);
+	qgpiBox->setBrush(qFuzzyCompare(os.qcBoxFill.alphaF(), static_cast< qreal >(0.0f)) ? Qt::NoBrush : os.qcBoxFill);
 	qgpiBox->setOpacity(1.0f);
 
 	qgpiBox->setVisible(os.bBox);
@@ -224,7 +219,7 @@ void OverlayEditorScene::resync() {
 
 	qgiGroup->setOpacity(os.fUser[tsColor]);
 
-	qgpiSelected = NULL;
+	qgpiSelected = nullptr;
 	qgriSelected->setVisible(false);
 }
 
@@ -232,14 +227,14 @@ void OverlayEditorScene::drawBackground(QPainter *p, const QRectF &rect) {
 	p->setBrushOrigin(0, 0);
 	p->fillRect(rect, backgroundBrush());
 
-	QRectF upscaled = OverlayUser::scaledRect(rect, 128.f / (uiSize * uiZoom));
+	QRectF upscaled = OverlayUser::scaledRect(rect, 128.f / static_cast< float >(uiSize * uiZoom));
 
 	{
 		int min = iroundf(upscaled.left());
 		int max = iroundf(ceil(upscaled.right()));
 
-		for (int i=min;i<=max;++i) {
-			qreal v = (i / 128.f) * uiSize * uiZoom;
+		for (int i = min; i <= max; ++i) {
+			qreal v = (i / 128) * static_cast< qreal >(uiSize * uiZoom);
 
 			if (i != 0)
 				p->setPen(QPen(QColor(128, 128, 128, 255), 0.0f));
@@ -254,8 +249,8 @@ void OverlayEditorScene::drawBackground(QPainter *p, const QRectF &rect) {
 		int min = iroundf(upscaled.top());
 		int max = iroundf(ceil(upscaled.bottom()));
 
-		for (int i=min;i<=max;++i) {
-			qreal v = (i / 128.f) * uiSize * uiZoom;
+		for (int i = min; i <= max; ++i) {
+			qreal v = (i / 128) * static_cast< qreal >(uiSize * uiZoom);
 
 			if (i != 0)
 				p->setPen(QPen(QColor(128, 128, 128, 255), 0.0f));
@@ -268,7 +263,7 @@ void OverlayEditorScene::drawBackground(QPainter *p, const QRectF &rect) {
 }
 
 QGraphicsPixmapItem *OverlayEditorScene::childAt(const QPointF &pos) {
-	QGraphicsItem *item = NULL;
+	QGraphicsItem *item = nullptr;
 
 	if (qgriSelected->isVisible()) {
 		if (qgriSelected->rect().contains(pos)) {
@@ -276,8 +271,8 @@ QGraphicsPixmapItem *OverlayEditorScene::childAt(const QPointF &pos) {
 		}
 	}
 
-	foreach(QGraphicsItem *qgi, items(Qt::AscendingOrder)) {
-		if (!qgi->isVisible() || ! qgraphicsitem_cast<QGraphicsPixmapItem *>(qgi))
+	foreach (QGraphicsItem *qgi, items(Qt::AscendingOrder)) {
+		if (!qgi->isVisible() || !qgraphicsitem_cast< QGraphicsPixmapItem * >(qgi))
 			continue;
 
 		QPointF qp = pos - qgi->pos();
@@ -285,39 +280,39 @@ QGraphicsPixmapItem *OverlayEditorScene::childAt(const QPointF &pos) {
 			item = qgi;
 		}
 	}
-	return static_cast<QGraphicsPixmapItem *>(item);
+	return static_cast< QGraphicsPixmapItem * >(item);
 }
 
 QRectF OverlayEditorScene::selectedRect() const {
-	const QRectF *qrf = NULL;
+	const QRectF *qrf = nullptr;
 
 	if (qgpiSelected == qgpiMuted)
-		qrf = & os.qrfMutedDeafened;
+		qrf = &os.qrfMutedDeafened;
 	else if (qgpiSelected == qgpiAvatar)
-		qrf = & os.qrfAvatar;
+		qrf = &os.qrfAvatar;
 	else if (qgpiSelected == qgpiChannel)
-		qrf = & os.qrfChannel;
+		qrf = &os.qrfChannel;
 	else if (qgpiSelected == qgpiName)
-		qrf = & os.qrfUserName;
+		qrf = &os.qrfUserName;
 
-	if (! qrf)
+	if (!qrf)
 		return QRectF();
 
 	return OverlayUser::scaledRect(*qrf, uiSize * uiZoom).toAlignedRect();
 }
 
 
-void OverlayEditorScene::mousePressEvent(QGraphicsSceneMouseEvent *event) {
-	QGraphicsScene::mousePressEvent(event);
+void OverlayEditorScene::mousePressEvent(QGraphicsSceneMouseEvent *e) {
+	QGraphicsScene::mousePressEvent(e);
 
-	if (event->isAccepted())
+	if (e->isAccepted())
 		return;
 
-	if (event->button() == Qt::LeftButton) {
-		event->accept();
+	if (e->button() == Qt::LeftButton) {
+		e->accept();
 
 		if (wfsHover == Qt::NoSection) {
-			qgpiSelected = childAt(event->scenePos());
+			qgpiSelected = childAt(e->scenePos());
 			if (qgpiSelected) {
 				qgriSelected->setRect(selectedRect());
 				qgriSelected->show();
@@ -326,26 +321,27 @@ void OverlayEditorScene::mousePressEvent(QGraphicsSceneMouseEvent *event) {
 			}
 		}
 
-		updateCursorShape(event->scenePos());
+		updateCursorShape(e->scenePos());
 	}
 }
 
-void OverlayEditorScene::mouseReleaseEvent(QGraphicsSceneMouseEvent *event) {
-	QGraphicsScene::mouseReleaseEvent(event);
+void OverlayEditorScene::mouseReleaseEvent(QGraphicsSceneMouseEvent *e) {
+	QGraphicsScene::mouseReleaseEvent(e);
 
-	if (event->isAccepted())
+	if (e->isAccepted())
 		return;
 
-	if (event->button() == Qt::LeftButton) {
-		event->accept();
+	if (e->button() == Qt::LeftButton) {
+		e->accept();
 
 		QRectF rect = qgriSelected->rect();
 
-		if (! qgpiSelected || (rect == selectedRect())) {
+		if (!qgpiSelected || (rect == selectedRect())) {
 			return;
 		}
 
-		QRectF scaled(rect.x() / (uiSize * uiZoom), rect.y() / (uiSize * uiZoom), rect.width() / (uiSize * uiZoom), rect.height() / (uiSize * uiZoom));
+		QRectF scaled(rect.x() / (uiSize * uiZoom), rect.y() / (uiSize * uiZoom), rect.width() / (uiSize * uiZoom),
+					  rect.height() / (uiSize * uiZoom));
 
 		if (qgpiSelected == qgpiMuted) {
 			os.qrfMutedDeafened = scaled;
@@ -365,21 +361,21 @@ void OverlayEditorScene::mouseReleaseEvent(QGraphicsSceneMouseEvent *event) {
 	}
 }
 
-void OverlayEditorScene::mouseMoveEvent(QGraphicsSceneMouseEvent *event) {
-	QGraphicsScene::mouseMoveEvent(event);
+void OverlayEditorScene::mouseMoveEvent(QGraphicsSceneMouseEvent *e) {
+	QGraphicsScene::mouseMoveEvent(e);
 
-	if (event->isAccepted())
+	if (e->isAccepted())
 		return;
 
-	if (qgpiSelected && (event->buttons() & Qt::LeftButton)) {
-		event->accept();
+	if (qgpiSelected && (e->buttons() & Qt::LeftButton)) {
+		e->accept();
 
 		if (wfsHover == Qt::NoSection)
 			return;
 
-		QPointF delta = event->scenePos() - event->buttonDownScenePos(Qt::LeftButton);
+		QPointF delta = e->scenePos() - e->buttonDownScenePos(Qt::LeftButton);
 
-		bool square = event->modifiers() & Qt::ShiftModifier;
+		bool square = e->modifiers() & Qt::ShiftModifier;
 
 		QRectF orig = selectedRect();
 		switch (wfsHover) {
@@ -469,12 +465,12 @@ void OverlayEditorScene::mouseMoveEvent(QGraphicsSceneMouseEvent *event) {
 
 		qgriSelected->setRect(orig);
 	} else {
-		updateCursorShape(event->scenePos());
+		updateCursorShape(e->scenePos());
 	}
 }
 
 void OverlayEditorScene::updateCursorShape(const QPointF &point) {
-	Qt::CursorShape	cs;
+	Qt::CursorShape cs;
 
 	if (qgriSelected->isVisible()) {
 		wfsHover = rectSection(qgriSelected->rect(), point);
@@ -508,7 +504,7 @@ void OverlayEditorScene::updateCursorShape(const QPointF &point) {
 	}
 
 
-	foreach(QGraphicsView *v, views()) {
+	foreach (QGraphicsView *v, views()) {
 		if (v->viewport()->cursor().shape() != cs) {
 			v->viewport()->setCursor(cs);
 
@@ -518,36 +514,36 @@ void OverlayEditorScene::updateCursorShape(const QPointF &point) {
 				QGraphicsProxyWidget *qgpw = p->graphicsProxyWidget();
 				if (qgpw) {
 					qgpw->setCursor(cs);
-					if (g.ocIntercept)
-						g.ocIntercept->updateMouse();
+					if (Global::get().ocIntercept)
+						Global::get().ocIntercept->updateMouse();
 				}
 			}
 		}
 	}
 }
 
-void OverlayEditorScene::contextMenuEvent(QGraphicsSceneContextMenuEvent *event) {
-	QGraphicsScene::contextMenuEvent(event);
+void OverlayEditorScene::contextMenuEvent(QGraphicsSceneContextMenuEvent *e) {
+	QGraphicsScene::contextMenuEvent(e);
 
-	if (event->isAccepted())
+	if (e->isAccepted())
 		return;
 
-	if (! event->widget())
+	if (!e->widget())
 		return;
 
-	QGraphicsPixmapItem *item = childAt(event->scenePos());
+	QGraphicsPixmapItem *item = childAt(e->scenePos());
 
-	QMenu qm(event->widget());
+	QMenu qm(e->widget());
 
-	QMenu *qmLayout = qm.addMenu(tr("Layout preset"));
+	QMenu *qmLayout              = qm.addMenu(tr("Layout preset"));
 	QAction *qaLayoutLargeAvatar = qmLayout->addAction(tr("Large square avatar"));
-	QAction *qaLayoutText = qmLayout->addAction(tr("Avatar and Name"));
+	QAction *qaLayoutText        = qmLayout->addAction(tr("Avatar and Name"));
 
-	QMenu *qmTrans = qm.addMenu(tr("User Opacity"));
+	QMenu *qmTrans        = qm.addMenu(tr("User Opacity"));
 	QActionGroup *qagUser = new QActionGroup(&qm);
 	QAction *userOpacity[8];
-	for (int i=0;i<8;++i) {
-		qreal o = (i + 1) / 8.0f;
+	for (int i = 0; i < 8; ++i) {
+		qreal o = (i + 1) / 8.0;
 
 		userOpacity[i] = new QAction(tr("%1%").arg(o * 100.0f, 0, 'f', 1), qagUser);
 		userOpacity[i]->setCheckable(true);
@@ -559,26 +555,26 @@ void OverlayEditorScene::contextMenuEvent(QGraphicsSceneContextMenuEvent *event)
 		qmTrans->addAction(userOpacity[i]);
 	}
 
-	QAction *color = NULL;
-	QAction *font = NULL;
+	QAction *color      = nullptr;
+	QAction *fontAction = nullptr;
 	QAction *objectOpacity[8];
-	for (int i=0;i<8;++i)
-		objectOpacity[i] = NULL;
-	QAction *boxpen[4] = { NULL, NULL, NULL, NULL};
-	QAction *boxpad[4] = { NULL, NULL, NULL, NULL};
-	QAction *boxpencolor = NULL;
-	QAction *boxfillcolor = NULL;
+	for (int i = 0; i < 8; ++i)
+		objectOpacity[i] = nullptr;
+	QAction *boxpen[4]    = { nullptr, nullptr, nullptr, nullptr };
+	QAction *boxpad[4]    = { nullptr, nullptr, nullptr, nullptr };
+	QAction *boxpencolor  = nullptr;
+	QAction *boxfillcolor = nullptr;
 
 	QAction *align[6];
-	for (int i=0;i<6;++i)
-		align[i] = NULL;
+	for (int i = 0; i < 6; ++i)
+		align[i] = nullptr;
 
 	if (item) {
 		qm.addSeparator();
-		QMenu *qmObjTrans = qm.addMenu(tr("Object Opacity"));
+		QMenu *qmObjTrans       = qm.addMenu(tr("Object Opacity"));
 		QActionGroup *qagObject = new QActionGroup(&qm);
-		for (int i=0;i<8;++i) {
-			qreal o = (i + 1) / 8.0f;
+		for (int i = 0; i < 8; ++i) {
+			qreal o = (i + 1) / 8.0;
 
 			objectOpacity[i] = new QAction(tr("%1%").arg(o * 100.0f, 0, 'f', 1), qagObject);
 			objectOpacity[i]->setCheckable(true);
@@ -634,8 +630,8 @@ void OverlayEditorScene::contextMenuEvent(QGraphicsSceneContextMenuEvent *event)
 			align[5]->setChecked(true);
 
 		if ((item != qgpiAvatar) && (item != qgpiMuted)) {
-			color = qm.addAction(tr("Color..."));
-			font = qm.addAction(tr("Font..."));
+			color      = qm.addAction(tr("Color..."));
+			fontAction = qm.addAction(tr("Font..."));
 		}
 	}
 
@@ -644,13 +640,13 @@ void OverlayEditorScene::contextMenuEvent(QGraphicsSceneContextMenuEvent *event)
 		QMenu *qmBox = qm.addMenu(tr("Bounding box"));
 		QMenu *qmPen = qmBox->addMenu(tr("Pen width"));
 		QMenu *qmPad = qmBox->addMenu(tr("Padding"));
-		boxpencolor = qmBox->addAction(tr("Pen color"));
+		boxpencolor  = qmBox->addAction(tr("Pen color"));
 		boxfillcolor = qmBox->addAction(tr("Fill color"));
 
 		QActionGroup *qagPen = new QActionGroup(qmPen);
 		QActionGroup *qagPad = new QActionGroup(qmPad);
-		for (int i=0;i<4;++i) {
-			qreal v = (i) ? powf(2.0f, -10 + i) : 0.0f;
+		for (int i = 0; i < 4; ++i) {
+			qreal v   = (i) ? powf(2.0f, static_cast< float >(-10 + i)) : 0.0f;
 			boxpen[i] = new QAction(QString::number(i), qagPen);
 			boxpen[i]->setData(v);
 			boxpen[i]->setCheckable(true);
@@ -667,21 +663,21 @@ void OverlayEditorScene::contextMenuEvent(QGraphicsSceneContextMenuEvent *event)
 		}
 	}
 
-	QAction *act = qm.exec(event->screenPos());
+	QAction *act = qm.exec(e->screenPos());
 
-	if (! act)
+	if (!act)
 		return;
 
-	for (int i=0;i<8;++i) {
+	for (int i = 0; i < 8; ++i) {
 		if (userOpacity[i] == act) {
-			float o = act->data().toReal();
+			float o           = static_cast< float >(act->data().toReal());
 			os.fUser[tsColor] = o;
 
 			qgiGroup->setOpacity(o);
 		}
 	}
 
-	for (int i=0;i<8;++i) {
+	for (int i = 0; i < 8; ++i) {
 		if (objectOpacity[i] == act) {
 			qreal o = act->data().toReal();
 
@@ -698,7 +694,7 @@ void OverlayEditorScene::contextMenuEvent(QGraphicsSceneContextMenuEvent *event)
 		}
 	}
 
-	for (int i=0;i<4;++i) {
+	for (int i = 0; i < 4; ++i) {
 		if (boxpen[i] == act) {
 			os.fBoxPenWidth = act->data().toReal();
 			moveBox();
@@ -708,19 +704,19 @@ void OverlayEditorScene::contextMenuEvent(QGraphicsSceneContextMenuEvent *event)
 		}
 	}
 
-	for (int i=0;i<6;++i) {
+	for (int i = 0; i < 6; ++i) {
 		if (align[i] == act) {
 			Qt::Alignment *aptr;
 			if (item == qgpiAvatar)
-				aptr = & os.qaAvatar;
+				aptr = &os.qaAvatar;
 			else if (item == qgpiChannel)
-				aptr = & os.qaChannel;
+				aptr = &os.qaChannel;
 			else if (item == qgpiMuted)
-				aptr = & os.qaMutedDeafened;
+				aptr = &os.qaMutedDeafened;
 			else
-				aptr = & os.qaUserName;
+				aptr = &os.qaUserName;
 
-			Qt::Alignment a = static_cast<Qt::Alignment>(act->data().toInt());
+			Qt::Alignment a = static_cast< Qt::Alignment >(act->data().toInt());
 			if (a & Qt::AlignHorizontal_Mask) {
 				*aptr = (*aptr & ~Qt::AlignHorizontal_Mask) | a;
 			} else {
@@ -732,28 +728,30 @@ void OverlayEditorScene::contextMenuEvent(QGraphicsSceneContextMenuEvent *event)
 	}
 
 	if (act == boxpencolor) {
-		QColor qc = QColorDialog::getColor(os.qcBoxPen, event->widget(), tr("Pick pen color"), QColorDialog::DontUseNativeDialog | QColorDialog::ShowAlphaChannel);
-		if (! qc.isValid())
+		QColor qc = QColorDialog::getColor(os.qcBoxPen, e->widget(), tr("Pick pen color"),
+										   QColorDialog::DontUseNativeDialog | QColorDialog::ShowAlphaChannel);
+		if (!qc.isValid())
 			return;
 		os.qcBoxPen = qc;
 		moveBox();
 	} else if (act == boxfillcolor) {
-		QColor qc = QColorDialog::getColor(os.qcBoxFill, event->widget(), tr("Pick fill color"), QColorDialog::DontUseNativeDialog | QColorDialog::ShowAlphaChannel);
-		if (! qc.isValid())
+		QColor qc = QColorDialog::getColor(os.qcBoxFill, e->widget(), tr("Pick fill color"),
+										   QColorDialog::DontUseNativeDialog | QColorDialog::ShowAlphaChannel);
+		if (!qc.isValid())
 			return;
 		os.qcBoxFill = qc;
 		moveBox();
 	} else if (act == color) {
-		QColor *col = NULL;
+		QColor *col = nullptr;
 		if (item == qgpiChannel)
-			col = & os.qcChannel;
+			col = &os.qcChannel;
 		else if (item == qgpiName)
-			col = & os.qcUserName[tsColor];
-		if (! col)
+			col = &os.qcUserName[tsColor];
+		if (!col)
 			return;
 
-		QColor qc = QColorDialog::getColor(*col, event->widget(), tr("Pick color"), QColorDialog::DontUseNativeDialog);
-		if (! qc.isValid())
+		QColor qc = QColorDialog::getColor(*col, e->widget(), tr("Pick color"), QColorDialog::DontUseNativeDialog);
+		if (!qc.isValid())
 			return;
 		qc.setAlpha(255);
 
@@ -762,10 +760,10 @@ void OverlayEditorScene::contextMenuEvent(QGraphicsSceneContextMenuEvent *event)
 
 		*col = qc;
 		updateSelected();
-	} else if (act == font) {
+	} else if (act == fontAction) {
 		QFont *fontptr = (item == qgpiChannel) ? &os.qfChannel : &os.qfUserName;
 
-		qgpiSelected = NULL;
+		qgpiSelected = nullptr;
 		qgriSelected->hide();
 
 		// QFontDialog doesn't really like graphics view. At all.
@@ -776,30 +774,30 @@ void OverlayEditorScene::contextMenuEvent(QGraphicsSceneContextMenuEvent *event)
 		qfd.setWindowTitle(tr("Pick font"));
 
 		int ret;
-		if (g.ocIntercept) {
-			QGraphicsProxyWidget *qgpw = new QGraphicsProxyWidget(NULL, Qt::Window);
+		if (Global::get().ocIntercept) {
+			QGraphicsProxyWidget *qgpw = new QGraphicsProxyWidget(nullptr, Qt::Window);
 			qgpw->setWidget(&qfd);
 
 			addItem(qgpw);
 
 			qgpw->setZValue(3.0f);
 			qgpw->setPanelModality(QGraphicsItem::PanelModal);
-			qgpw->setPos(- qgpw->boundingRect().width() / 2.0f, - qgpw->boundingRect().height() / 2.0f);
+			qgpw->setPos(-qgpw->boundingRect().width() / 2.0f, -qgpw->boundingRect().height() / 2.0f);
 			qgpw->show();
 
 			ret = qfd.exec();
 
 			qgpw->hide();
-			qgpw->setWidget(NULL);
+			qgpw->setWidget(nullptr);
 			delete qgpw;
 		} else {
-			Qt::WindowFlags wf = g.mw->windowFlags();
+			Qt::WindowFlags wf = Global::get().mw->windowFlags();
 			if (wf.testFlag(Qt::WindowStaysOnTopHint))
 				qfd.setWindowFlags(qfd.windowFlags() | Qt::WindowStaysOnTopHint);
 			ret = qfd.exec();
 		}
 
-		if (! ret)
+		if (!ret)
 			return;
 		*fontptr = qfd.selectedFont();
 
@@ -840,10 +838,10 @@ static qreal distancePointLine(const QPointF &a, const QPointF &b, const QPointF
 Qt::WindowFrameSection OverlayEditorScene::rectSection(const QRectF &qrf, const QPointF &qp, qreal dist) {
 	qreal left, right, top, bottom;
 
-	top = distancePointLine(qrf.topLeft(), qrf.topRight(), qp);
+	top    = distancePointLine(qrf.topLeft(), qrf.topRight(), qp);
 	bottom = distancePointLine(qrf.bottomLeft(), qrf.bottomRight(), qp);
-	left = distancePointLine(qrf.topLeft(), qrf.bottomLeft(), qp);
-	right = distancePointLine(qrf.topRight(), qrf.bottomRight(), qp);
+	left   = distancePointLine(qrf.topLeft(), qrf.bottomLeft(), qp);
+	right  = distancePointLine(qrf.topRight(), qrf.bottomRight(), qp);
 
 	if ((top < dist) && (top < bottom)) {
 		if ((left < dist) && (left < right))
@@ -867,3 +865,5 @@ Qt::WindowFrameSection OverlayEditorScene::rectSection(const QRectF &qrf, const
 
 	return Qt::NoSection;
 }
+
+#undef SCALESIZE
