@@ -1,15 +1,13 @@
-// Copyright 2005-2019 The Mumble Developers. All rights reserved.
+// Copyright 2007-2022 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
 
-#include "mumble_pch.hpp"
-
 #include "Overlay.h"
 #include "OverlayConfig.h"
 
 void Overlay::platformInit() {
-	d = NULL;
+	d = nullptr;
 }
 
 void Overlay::setActiveInternal(bool) {
