@@ -1,4 +1,4 @@
-// Copyright 2005-2019 The Mumble Developers. All rights reserved.
+// Copyright 2018-2022 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
@@ -9,8 +9,7 @@
 #include <QIcon>
 #include <QString>
 
-class SvgIcon
-{
+class SvgIcon {
 public:
 	/// addSvgPixmapsToIcon renders the SVG file at |fn| in various
 	/// common sizes from 8x8 up to 256x256 and adds the resulting
