@@ -1,4 +1,4 @@
-// Copyright 2005-2019 The Mumble Developers. All rights reserved.
+// Copyright 2014-2022 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
@@ -38,9 +38,6 @@
 
 #import <AppKit/AppKit.h>
 
-#include "mumble_pch.hpp"
-
-#include "Global.h"
 #include "TextToSpeech.h"
 
 @interface MUSpeechSynthesizerPrivateHelper : NSObject {
