@@ -1,35 +1,41 @@
-// Copyright 2005-2019 The Mumble Developers. All rights reserved.
+// Copyright 2009-2022 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
 
-#include "mumble_pch.hpp"
-
 #include "Usage.h"
 
 #include "ClientUser.h"
 #include "LCD.h"
-#include "Global.h"
 #include "NetworkConfig.h"
 #include "OSInfo.h"
 #include "Version.h"
+#include "Global.h"
+
+#include <QtCore/QTimer>
+#include <QtNetwork/QHostAddress>
+#include <QtNetwork/QNetworkAccessManager>
+#include <QtNetwork/QNetworkReply>
+#include <QtXml/QDomElement>
 
 Usage::Usage(QObject *p) : QObject(p) {
 	qbReport.open(QBuffer::ReadWrite);
 	qdsReport.setDevice(&qbReport);
 	qdsReport.setVersion(QDataStream::Qt_4_4);
-	qdsReport << static_cast<unsigned int>(2);
+	qdsReport << static_cast< unsigned int >(2);
 
 	// Wait 10 minutes (so we know they're actually using this), then...
 	QTimer::singleShot(60 * 10 * 1000, this, SLOT(registerUsage()));
 }
 
 void Usage::registerUsage() {
-	if (! g.s.bUsage || g.s.uiUpdateCounter == 0) // Only register usage if allowed by the user and first wizard run has finished
+	if (!Global::get().s.bUsage
+		|| Version::get() < Version::fromComponents(
+			   1, 2, 3)) // Only register usage if allowed by the user and first wizard run has finished
 		return;
 
 	QDomDocument doc;
-	QDomElement root=doc.createElement(QLatin1String("usage"));
+	QDomElement root = doc.createElement(QLatin1String("usage"));
 	doc.appendChild(root);
 
 	QDomElement tag;
@@ -37,19 +43,19 @@ void Usage::registerUsage() {
 
 	OSInfo::fillXml(doc, root);
 
-	tag=doc.createElement(QLatin1String("in"));
+	tag = doc.createElement(QLatin1String("in"));
 	root.appendChild(tag);
-	t=doc.createTextNode(g.s.qsAudioInput);
+	t = doc.createTextNode(Global::get().s.qsAudioInput);
 	tag.appendChild(t);
 
-	tag=doc.createElement(QLatin1String("out"));
+	tag = doc.createElement(QLatin1String("out"));
 	root.appendChild(tag);
-	t=doc.createTextNode(g.s.qsAudioOutput);
+	t = doc.createTextNode(Global::get().s.qsAudioOutput);
 	tag.appendChild(t);
 
-	tag=doc.createElement(QLatin1String("lcd"));
+	tag = doc.createElement(QLatin1String("lcd"));
 	root.appendChild(tag);
-	t=doc.createTextNode(QString::number(g.lcd->hasDevices() ? 1 : 0));
+	t = doc.createTextNode(QString::number(Global::get().lcd->hasDevices() ? 1 : 0));
 	tag.appendChild(t);
 
 	QBuffer *qb = new QBuffer();
@@ -60,9 +66,8 @@ void Usage::registerUsage() {
 	Network::prepareRequest(req);
 	req.setHeader(QNetworkRequest::ContentTypeHeader, QLatin1String("text/xml"));
 
-	QNetworkReply *rep = g.nam->post(req, qb);
+	QNetworkReply *rep = Global::get().nam->post(req, qb);
 	qb->setParent(rep);
 
 	connect(rep, SIGNAL(finished()), rep, SLOT(deleteLater()));
 }
-
