@@ -1,15 +1,11 @@
-// Copyright 2005-2019 The Mumble Developers. All rights reserved.
+// Copyright 2015-2022 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
 
-#include "mumble_pch.hpp"
-
 #include "UserLockFile.h"
 
-UserLockFile::UserLockFile(const QString &lockFilePath)
-	: m_handle(0)
-	, m_path(lockFilePath) {
+UserLockFile::UserLockFile(const QString &lockFilePath) : m_handle(0), m_path(lockFilePath) {
 }
 
 UserLockFile::~UserLockFile() {
@@ -25,15 +21,8 @@ bool UserLockFile::acquire() {
 		return false;
 	}
 
-	m_handle = CreateFile(
-		reinterpret_cast<const wchar_t *>(m_path.utf16()),
-		GENERIC_WRITE,
-		0,
-		NULL,
-		CREATE_ALWAYS,
-		FILE_ATTRIBUTE_HIDDEN,
-		NULL
-	);
+	m_handle = CreateFile(reinterpret_cast< const wchar_t * >(m_path.utf16()), GENERIC_WRITE, 0, nullptr, CREATE_ALWAYS,
+						  FILE_ATTRIBUTE_HIDDEN, nullptr);
 	if (m_handle == INVALID_HANDLE_VALUE && GetLastError() == ERROR_SHARING_VIOLATION) {
 		return false;
 	}
